@@ -1,6 +1,8 @@
+// © 2016 and later: Unicode, Inc. and others.
+// License & terms of use: http://www.unicode.org/copyright.html
 /*
  **********************************************************************
- *   Copyright (C) 2003-2005, International Business Machines
+ *   Copyright (C) 2003-2008, International Business Machines
  *   Corporation and others.  All Rights Reserved.
  **********************************************************************
  */
@@ -96,7 +98,7 @@ public:
      *
      * Note: Subclass arrays will also be reset and not deleted.
      *
-     * @draft ICU 3.6
+     * @stable ICU 3.6
      */
     inline void reset();
 
@@ -138,7 +140,7 @@ public:
      *
      * @param limit is the limit index to add to the array.
      *
-     * @return the run index where the limit index was stored, or -1 if the limit index cannt be stored.
+     * @return the run index where the limit index was stored, or -1 if the limit index cannot be stored.
      *
      * @see init
      * @see grow
@@ -220,19 +222,19 @@ private:
 };
 
 inline RunArray::RunArray()
-    : UObject(), fClientArrays(FALSE), fLimits(NULL), fCount(0), fCapacity(0)
+    : UObject(), fClientArrays(false), fLimits(nullptr), fCount(0), fCapacity(0)
 {
     // nothing else to do...
 }
 
 inline RunArray::RunArray(const RunArray & /*other*/)
-    : UObject(), fClientArrays(FALSE), fLimits(NULL), fCount(0), fCapacity(0)
+    : UObject(), fClientArrays(false), fLimits(nullptr), fCount(0), fCapacity(0)
 {
     // nothing else to do...
 }
 
 inline RunArray::RunArray(const le_int32 *limits, le_int32 count)
-    : UObject(), fClientArrays(TRUE), fLimits(limits), fCount(count), fCapacity(count)
+    : UObject(), fClientArrays(true), fLimits(limits), fCount(count), fCapacity(count)
 {
     // nothing else to do...
 }
@@ -308,7 +310,7 @@ public:
     virtual ~FontRuns();
 
     /**
-     * Get the <code>LEFontInstance</code> object assoicated with the given run
+     * Get the <code>LEFontInstance</code> object associated with the given run
      * of text. Use <code>RunArray::getLimit(run)</code> to get the corresponding
      * limit index.
      *
@@ -381,13 +383,13 @@ private:
 };
 
 inline FontRuns::FontRuns()
-    : RunArray(0), fFonts(NULL)
+    : RunArray(0), fFonts(nullptr)
 {
     // nothing else to do...
 }
 
 inline FontRuns::FontRuns(const FontRuns & /*other*/)
-    : RunArray(0), fFonts(NULL)
+    : RunArray(0), fFonts(nullptr)
 {
     // nothing else to do...
 }
@@ -445,7 +447,7 @@ public:
     virtual ~LocaleRuns();
 
     /**
-     * Get the <code>Locale</code> object assoicated with the given run
+     * Get the <code>Locale</code> object associated with the given run
      * of text. Use <code>RunArray::getLimit(run)</code> to get the corresponding
      * limit index.
      *
@@ -502,6 +504,11 @@ protected:
     virtual void init(le_int32 capacity);
     virtual void grow(le_int32 capacity);
 
+    /**
+     * @internal
+     */
+    const Locale **fLocales;
+
 private:
 
     inline LocaleRuns();
@@ -513,18 +520,16 @@ private:
      * for ICU "poor man's RTTI".
      */
     static const char fgClassID;
-
-    const Locale **fLocales;
 };
 
 inline LocaleRuns::LocaleRuns()
-    : RunArray(0), fLocales(NULL)
+    : RunArray(0), fLocales(nullptr)
 {
     // nothing else to do...
 }
 
 inline LocaleRuns::LocaleRuns(const LocaleRuns & /*other*/)
-    : RunArray(0), fLocales(NULL)
+    : RunArray(0), fLocales(nullptr)
 {
     // nothing else to do...
 }
@@ -580,7 +585,7 @@ public:
     virtual ~ValueRuns();
 
     /**
-     * Get the integer value assoicated with the given run
+     * Get the integer value associated with the given run
      * of text. Use <code>RunArray::getLimit(run)</code> to get the corresponding
      * limit index.
      *
@@ -652,13 +657,13 @@ private:
 };
 
 inline ValueRuns::ValueRuns()
-    : RunArray(0), fValues(NULL)
+    : RunArray(0), fValues(nullptr)
 {
     // nothing else to do...
 }
 
 inline ValueRuns::ValueRuns(const ValueRuns & /*other*/)
-    : RunArray(0), fValues(NULL)
+    : RunArray(0), fValues(nullptr)
 {
     // nothing else to do...
 }
