@@ -5,6 +5,7 @@
  * Corporation and others. All Rights Reserved.
  ********************************************************************/
 
+#include <stdbool.h>
 #include <string.h>
 #include "unicode/utypes.h"
 #include "unicode/uscript.h"
@@ -72,7 +73,9 @@ void TestUScriptCodeAPI(){
         "asfdasd", "5464", "12235",
         /* test the last index */
         "zyyy", "YI",
-        NULL  
+         /* test other cases that are ambiguous (script alias vs language tag) */
+         "han", "mro", "nko", "old-hungarian", "new-tai-lue",
+       NULL  
         };
         UScriptCode expected[] ={
             /* locales should return */
@@ -94,7 +97,10 @@ void TestUScriptCodeAPI(){
             USCRIPT_TAGBANWA, USCRIPT_ARABIC,
             /* bogus names should return invalid code */
             USCRIPT_INVALID_CODE, USCRIPT_INVALID_CODE, USCRIPT_INVALID_CODE,
+            /* test the last index */
             USCRIPT_COMMON, USCRIPT_YI,
+            /* test other cases that are ambiguous (script alias vs language tag) */
+            USCRIPT_HAN, USCRIPT_MRO, USCRIPT_NKO, USCRIPT_OLD_HUNGARIAN, USCRIPT_NEW_TAI_LUE,
         };
 
         UErrorCode err = U_ZERO_ERROR;
@@ -316,7 +322,7 @@ void TestUScriptCodeAPI(){
         };
         UScriptCode code = USCRIPT_INVALID_CODE;
         UErrorCode status = U_ZERO_ERROR;
-        UBool passed = TRUE;
+        UBool passed = true;
 
         for(i=0; i<UPRV_LENGTHOF(codepoints); ++i){
             code = uscript_getScript(codepoints[i],&status);
@@ -325,7 +331,7 @@ void TestUScriptCodeAPI(){
                     code != (UScriptCode)u_getIntPropertyValue(codepoints[i], UCHAR_SCRIPT)
                 ) {
                     log_err("uscript_getScript for codepoint \\U%08X failed\n",codepoints[i]);
-                    passed = FALSE;
+                    passed = false;
                 }
             }else{
                 log_err("uscript_getScript for codepoint \\U%08X failed. Error: %s\n", 
@@ -334,7 +340,7 @@ void TestUScriptCodeAPI(){
             }
         }
         
-        if(passed==FALSE){
+        if(passed==false){
            log_err("uscript_getScript failed.\n");
         }      
     }
@@ -421,6 +427,10 @@ void TestUScriptCodeAPI(){
             "Elymaic", "Nyiakeng_Puachue_Hmong", "Nandinagari", "Wancho",
             // new in ICU 66
             "Chorasmian", "Dives_Akuru", "Khitan_Small_Script", "Yezidi",
+            // new in ICU 70
+            "Cypro_Minoan", "Old_Uyghur", "Tangsa", "Toto", "Vithkuqi",
+            // new in ICU 72
+            "Kawi", "Nag_Mundari",
         };
         static const char* expectedShort[] = {
             "Bali", "Batk", "Blis", "Brah", "Cham", "Cirt", "Cyrs", "Egyd", "Egyh", "Egyp",
@@ -457,6 +467,10 @@ void TestUScriptCodeAPI(){
             "Elym", "Hmnp", "Nand", "Wcho",
             // new in ICU 66
             "Chrs", "Diak", "Kits", "Yezi",
+            // new in ICU 70
+            "Cpmn", "Ougr", "Tnsa", "Toto", "Vith",
+            // new in ICU 72
+            "Kawi", "Nagm",
         };
         int32_t j = 0;
         if(UPRV_LENGTHOF(expectedLong)!=(USCRIPT_CODE_LIMIT-USCRIPT_BALINESE)) {
@@ -552,14 +566,14 @@ void TestHasScript() {
 }
 
 static UBool scriptsContain(UScriptCode scripts[], int32_t length, UScriptCode script) {
-    UBool contain=FALSE;
+    UBool contain=false;
     int32_t prev=-1, i;
     for(i=0; i<length; ++i) {
         int32_t s=scripts[i];
         if(s<=prev) {
             log_err("uscript_getScriptExtensions() not in sorted order: %d %d\n", (int)prev, (int)s);
         }
-        if(s==script) { contain=TRUE; }
+        if(s==script) { contain=true; }
     }
     return contain;
 }
@@ -724,13 +738,13 @@ void TestBinaryValues() {
     static const char *const trueValues[]={ "Y", "Yes", "T", "True" };
     int32_t i;
     for(i=0; i<UPRV_LENGTHOF(falseValues); ++i) {
-        if(FALSE!=u_getPropertyValueEnum(UCHAR_ALPHABETIC, falseValues[i])) {
-            log_data_err("u_getPropertyValueEnum(UCHAR_ALPHABETIC, \"%s\")!=FALSE (Are you missing data?)\n", falseValues[i]);
+        if(false!=u_getPropertyValueEnum(UCHAR_ALPHABETIC, falseValues[i])) {
+            log_data_err("u_getPropertyValueEnum(UCHAR_ALPHABETIC, \"%s\")!=false (Are you missing data?)\n", falseValues[i]);
         }
     }
     for(i=0; i<UPRV_LENGTHOF(trueValues); ++i) {
-        if(TRUE!=u_getPropertyValueEnum(UCHAR_ALPHABETIC, trueValues[i])) {
-            log_data_err("u_getPropertyValueEnum(UCHAR_ALPHABETIC, \"%s\")!=TRUE (Are you missing data?)\n", trueValues[i]);
+        if(true!=u_getPropertyValueEnum(UCHAR_ALPHABETIC, trueValues[i])) {
+            log_data_err("u_getPropertyValueEnum(UCHAR_ALPHABETIC, \"%s\")!=true (Are you missing data?)\n", trueValues[i]);
         }
     }
 }
