@@ -17,8 +17,9 @@
 /****************************************************************************/
 
 
-#include <stdlib.h>
+#include <stdbool.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include "unicode/utypes.h"
 #include "unicode/ustring.h"
@@ -516,7 +517,7 @@ static void Test_UChar_UTF8_API(void){
     char* u8Target = u8Temp;
     int32_t u8TargetLength =0;
     int32_t u8DestLen =0;
-    UBool failed = FALSE;
+    UBool failed = false;
     int i= 0;
     int32_t numSubstitutions;
 
@@ -541,7 +542,7 @@ static void Test_UChar_UTF8_API(void){
         else {
             log_err("Should have gotten U_BUFFER_OVERFLOW_ERROR");
         }
-        failed = FALSE;
+        failed = false;
         /*for(i=0; i< u8DestLen; i++){
             printf("0x%04X, ",u8Target[i]);
             if(i%10==0){
@@ -551,7 +552,7 @@ static void Test_UChar_UTF8_API(void){
         /*for(i=0; i< u8DestLen; i++){
             if(u8Target[i] != src8[i]){
                 log_verbose("u_strToUTF8() failed expected: %04X got: %04X \n", src8[i], u8Target[i]);
-                failed =TRUE;
+                failed =true;
             }
         }
         if(failed){
@@ -583,12 +584,12 @@ static void Test_UChar_UTF8_API(void){
         }*/
 
         if(U_FAILURE(err) || uDestLen != uTargetLength || uTarget[uTargetLength] != 0xfff0) {
-            failed = TRUE;
+            failed = true;
         }
         for(i=0; i< uSrcLen; i++){
             if(uTarget[i] != src16[i]){
                 log_verbose("u_strFromUTF8() failed expected: \\u%04X got: \\u%04X at index: %i \n", src16[i] ,uTarget[i],i);
-                failed =TRUE;
+                failed =true;
             }
         }
         if(failed){
@@ -603,7 +604,7 @@ static void Test_UChar_UTF8_API(void){
         uTargetLength = 0;
         uSrcLen =-1;
         u8TargetLength=0;
-        failed = FALSE;
+        failed = false;
         /* preflight */
         u_strToUTF8(NULL,u8TargetLength, &u8DestLen, uSrc, uSrcLen,&err);
         if(err == U_BUFFER_OVERFLOW_ERROR){
@@ -617,7 +618,7 @@ static void Test_UChar_UTF8_API(void){
         else {
             log_err("Should have gotten U_BUFFER_OVERFLOW_ERROR");
         }
-        failed = FALSE;
+        failed = false;
         /*for(i=0; i< u8DestLen; i++){
             printf("0x%04X, ",u8Target[i]);
             if(i%10==0){
@@ -627,7 +628,7 @@ static void Test_UChar_UTF8_API(void){
         /*for(i=0; i< u8DestLen; i++){
             if(u8Target[i] != src8[i]){
                 log_verbose("u_strToUTF8() failed expected: %04X got: %04X \n", src8[i], u8Target[i]);
-                failed =TRUE;
+                failed =true;
             }
         }
         if(failed){
@@ -658,7 +659,7 @@ static void Test_UChar_UTF8_API(void){
         for(i=0; i< uSrcLen; i++){
             if(uTarget[i] != src16[i]){
                 log_verbose("u_strFromUTF8() failed expected: \\u%04X got: \\u%04X at index: %i \n", src16[i] ,uTarget[i],i);
-                failed =TRUE;
+                failed =true;
             }
         }
         if(failed){
@@ -871,11 +872,11 @@ equalAnyFFFD(const UChar *s, const UChar *t, int32_t length) {
         c1=*s++;
         c2=*t++;
         if(c1!=c2 && c2!=0xfffd) {
-            return FALSE;
+            return false;
         }
         --length;
     }
-    return TRUE;
+    return true;
 }
 
 /* test u_strFromUTF8Lenient() */
@@ -1171,7 +1172,7 @@ static void Test_UChar_WCHART_API(void){
     wchar_t* wDest = NULL;
     int32_t wDestLen = 0;
     int32_t reqLen= 0 ;
-    UBool failed = FALSE;
+    UBool failed = false;
     UChar* uDest = NULL;
     int32_t uDestLen = 0;
     int i =0;
@@ -1225,12 +1226,12 @@ static void Test_UChar_WCHART_API(void){
         for(i=0; i< uSrcLen; i++){
             if(uDest[i] != src16j[i]){
                 log_verbose("u_str*WCS() failed for unterminated string expected: \\u%04X got: \\u%04X at index: %i \n", src16j[i] ,uDest[i],i);
-                failed =TRUE;
+                failed =true;
             }
         }
 
         if(U_FAILURE(err)){
-            failed = TRUE;
+            failed = true;
         }
         if(failed){
             log_err("u_strToWCS() failed \n");
@@ -1270,13 +1271,13 @@ static void Test_UChar_WCHART_API(void){
          for(i=0; i< uSrcLen; i++){
             if(uDest[i] != src16WithNulls[i]){
                 log_verbose("u_str*WCS() failed for string with nulls expected: \\u%04X got: \\u%04X at index: %i \n", src16WithNulls[i] ,uDest[i],i);
-                failed =TRUE;
+                failed =true;
             }
          }
         }
 
         if(U_FAILURE(err)){
-            failed = TRUE;
+            failed = true;
         }
         if(failed){
             log_err("u_strToWCS() failed \n");
@@ -1320,13 +1321,13 @@ static void Test_UChar_WCHART_API(void){
          for(i=0; i< uSrcLen; i++){
             if(uDest[i] != src16j[i]){
                 log_verbose("u_str*WCS() failed for null terminated string expected: \\u%04X got: \\u%04X at index: %i \n", src16j[i] ,uDest[i],i);
-                failed =TRUE;
+                failed =true;
             }
          }
         }
 
         if(U_FAILURE(err)){
-            failed = TRUE;
+            failed = true;
         }
         if(failed){
             log_err("u_strToWCS() failed \n");
@@ -1437,7 +1438,7 @@ Test_WCHART_LongString(){
     int32_t uDestLen =0;
     wchar_t* wDest = NULL;
     UChar* uDest = NULL;
-    UBool failed = FALSE;
+    UBool failed = false;
 
     log_verbose("Loaded string of %d UChars\n", uSrcLen);
 
@@ -1493,12 +1494,12 @@ Test_WCHART_LongString(){
     for(i=0; i< uSrcLen; i++){
         if(uDest[i] != str[i]){
             log_verbose("u_str*WCS() failed for null terminated string expected: \\u%04X got: \\u%04X at index: %i \n", str[i], uDest[i],i);
-            failed =TRUE;
+            failed =true;
         }
     }
 
     if(U_FAILURE(status)){
-        failed = TRUE;
+        failed = true;
     }
     if(failed){
         log_err("u_strToWCS() failed \n");
