@@ -14,6 +14,7 @@
 
 #if !UCONFIG_NO_TRANSLITERATION
 
+#include <stdbool.h>
 #include <stdlib.h>
 #include <string.h>
 #include "unicode/utrans.h"
@@ -443,7 +444,7 @@ static void TestSimpleRules() {
     /* Example: rules 1. ab>x|y
      *                2. yc>z
      *
-     * []|eabcd  start - no match, copy e to tranlated buffer
+     * []|eabcd  start - no match, copy e to translated buffer
      * [e]|abcd  match rule 1 - copy output & adjust cursor
      * [ex|y]cd  match rule 2 - copy output & adjust cursor
      * [exz]|d   no match, copy d to transliterated buffer
@@ -585,7 +586,7 @@ static void TestExtractBetween() {
 static const UChar transSimpleID[] = { 0x79,0x6F,0x2D,0x79,0x6F,0x5F,0x42,0x4A,0 }; /* "yo-yo_BJ" */
 static const char* transSimpleCName = "yo-yo_BJ";
 
-enum { kUBufMax = 256 };
+enum { kUBufMax = 512 };
 static void TestGetRulesAndSourceSet() {
     UErrorCode status = U_ZERO_ERROR;
     UTransliterator *utrans = utrans_openU(transSimpleID, -1, UTRANS_FORWARD, NULL, 0, NULL, &status);
@@ -595,29 +596,29 @@ static void TestGetRulesAndSourceSet() {
         int32_t ulen;
 
         status = U_ZERO_ERROR;
-        ulen = utrans_toRules(utrans, FALSE, ubuf, kUBufMax, &status);
+        ulen = utrans_toRules(utrans, false, ubuf, kUBufMax, &status);
         if ( U_FAILURE(status) || ulen <= 50 || ulen >= 100) {
             log_err("FAIL: utrans_toRules unescaped, expected noErr and len 50-100, got error=%s and len=%d\n",
                     u_errorName(status), ulen);
         }
 
         status = U_ZERO_ERROR;
-        ulen = utrans_toRules(utrans, FALSE, NULL, 0, &status);
+        ulen = utrans_toRules(utrans, false, NULL, 0, &status);
         if ( status != U_BUFFER_OVERFLOW_ERROR || ulen <= 50 || ulen >= 100) {
             log_err("FAIL: utrans_toRules unescaped, expected U_BUFFER_OVERFLOW_ERROR and len 50-100, got error=%s and len=%d\n",
                     u_errorName(status), ulen);
         }
 
         status = U_ZERO_ERROR;
-        ulen = utrans_toRules(utrans, TRUE, ubuf, kUBufMax, &status);
+        ulen = utrans_toRules(utrans, true, ubuf, kUBufMax, &status);
         if ( U_FAILURE(status) || ulen <= 100 || ulen >= 200) {
             log_err("FAIL: utrans_toRules escaped, expected noErr and len 100-200, got error=%s and len=%d\n",
                     u_errorName(status), ulen);
         }
 
         status = U_ZERO_ERROR;
-        uset = utrans_getSourceSet(utrans, FALSE, NULL, &status);
-        ulen = uset_toPattern(uset, ubuf, kUBufMax, FALSE, &status);
+        uset = utrans_getSourceSet(utrans, false, NULL, &status);
+        ulen = uset_toPattern(uset, ubuf, kUBufMax, false, &status);
         uset_close(uset);
         if ( U_FAILURE(status) || ulen <= 4 || ulen >= 20) {
             log_err("FAIL: utrans_getSourceSet useFilter, expected noErr and len 4-20, got error=%s and len=%d\n",
@@ -625,8 +626,8 @@ static void TestGetRulesAndSourceSet() {
         }
 
         status = U_ZERO_ERROR;
-        uset = utrans_getSourceSet(utrans, TRUE, NULL, &status);
-        ulen = uset_toPattern(uset, ubuf, kUBufMax, FALSE, &status);
+        uset = utrans_getSourceSet(utrans, true, NULL, &status);
+        ulen = uset_toPattern(uset, ubuf, kUBufMax, false, &status);
         uset_close(uset);
         if ( U_FAILURE(status) || ulen <= 4 || ulen >= 20) {
             log_err("FAIL: utrans_getSourceSet ignoreFilter, expected noErr and len 4-20, got error=%s and len=%d\n",
@@ -655,7 +656,7 @@ static const TransIDSourceTarg dataVarCompItems[] = {
       "\\uFF33\\uFF41\\uFF4D\\uFF50\\uFF4C\\uFF45\\u3000\\uFF54\\uFF45\\uFF58\\uFF54\\uFF0C\\u3000\\u30B5\\u30F3\\u30D7\\u30EB\\u30C6\\u30AD\\u30B9\\u30C8\\uFF0E" },
     { "Han-Latin/Names; Latin-Bopomofo",
        "\\u4E07\\u4FDF\\u919C\\u5974\\u3001\\u533A\\u695A\\u826F\\u3001\\u4EFB\\u70E8\\u3001\\u5CB3\\u98DB",
-       "\\u3107\\u311B\\u02CB \\u3111\\u3127\\u02CA \\u3114\\u3121\\u02C7 \\u310B\\u3128\\u02CA\\u3001 \\u3121 \\u3114\\u3128\\u02C7 \\u310C\\u3127\\u3124\\u02CA\\u3001 \\u3116\\u3123\\u02CA \\u3127\\u311D\\u02CB\\u3001 \\u3129\\u311D\\u02CB \\u3108\\u311F" },
+       "\\u3107\\u311B\\u02CB \\u3111\\u3127\\u02CA \\u3114\\u3121\\u02C7 \\u310B\\u3128\\u02CA, \\u3121 \\u3114\\u3128\\u02C7 \\u310C\\u3127\\u3124\\u02CA, \\u3116\\u3123\\u02CA \\u3127\\u311D\\u02CB, \\u3129\\u311D\\u02CB \\u3108\\u311F" },
     { "Greek-Latin",
       "\\u1F08 \\u1FBC \\u1F89 \\u1FEC",
       "A \\u0100I H\\u0100I RH" },
@@ -670,7 +671,7 @@ static const TransIDSourceTarg dataVarCompItems[] = {
     { NULL, NULL, NULL }
 };
 
-enum { kBBufMax = 384 };
+enum { kBBufMax = 1024 };
 static void TestDataVariantsCompounds() {
     const TransIDSourceTarg* itemsPtr;
     for (itemsPtr = dataVarCompItems; itemsPtr->transID != NULL; itemsPtr++) {
@@ -693,8 +694,8 @@ static void TestDataVariantsCompounds() {
             int32_t expectLen =  u_unescape(itemsPtr->targetText, expect, kUBufMax);
             if (textLen != expectLen || u_strncmp(text, expect, textLen) != 0) {
                 char btext[kBBufMax], bexpect[kBBufMax];
-                u_austrncpy(btext, text, textLen);
-                u_austrncpy(bexpect, expect, expectLen);
+                u_austrncpy(btext, text, kUBufMax);
+                u_austrncpy(bexpect, expect, kUBufMax);
                 log_err("FAIL: utrans_transUChars(%s),\n       expect %s\n       get    %s\n", itemsPtr->transID, bexpect, btext);
             }
         }
