@@ -1,3 +1,5 @@
+// © 2016 and later: Unicode, Inc. and others.
+// License & terms of use: http://www.unicode.org/copyright.html
 /********************************************************************
  * COPYRIGHT:
  * Copyright (c) 1997-2016, International Business Machines Corporation and
@@ -24,7 +26,7 @@ CollationIteratorTest::CollationIteratorTest()
  : test1("What subset of all possible test cases?", ""),
    test2("has the highest probability of detecting", "")
 {
-    en_us = (RuleBasedCollator *)Collator::createInstance(Locale::getUS(), status);
+    en_us = dynamic_cast<RuleBasedCollator*>(Collator::createInstance(Locale::getUS(), status));
     if(U_FAILURE(status)) {
       delete en_us;
       en_us = 0;
@@ -46,7 +48,7 @@ CollationIteratorTest::~CollationIteratorTest()
 void CollationIteratorTest::TestUnicodeChar()
 {
     CollationElementIterator *iter;
-    UChar codepoint;
+    char16_t codepoint;
     UnicodeString source;
     
     for (codepoint = 1; codepoint < 0xFFFE;)
@@ -90,11 +92,11 @@ void CollationIteratorTest::TestPrevious(/* char* par */)
 
     // Test with a contracting character sequence
     UnicodeString source;
-    RuleBasedCollator *c1 = NULL;
+    RuleBasedCollator *c1 = nullptr;
     c1 = new RuleBasedCollator(
         (UnicodeString)"&a,A < b,B < c,C, d,D < z,Z < ch,cH,Ch,CH", status);
 
-    if (c1 == NULL || U_FAILURE(status))
+    if (c1 == nullptr || U_FAILURE(status))
     {
         errln("Couldn't create a RuleBasedCollator with a contracting sequence.");
         delete c1;
@@ -108,10 +110,10 @@ void CollationIteratorTest::TestPrevious(/* char* par */)
     delete c1;
 
     // Test with an expanding character sequence
-    RuleBasedCollator *c2 = NULL;
+    RuleBasedCollator *c2 = nullptr;
     c2 = new RuleBasedCollator((UnicodeString)"&a < b < c/abd < d", status);
 
-    if (c2 == NULL || U_FAILURE(status))
+    if (c2 == nullptr || U_FAILURE(status))
     {
         errln("Couldn't create a RuleBasedCollator with an expanding sequence.");
         delete c2;
@@ -125,10 +127,10 @@ void CollationIteratorTest::TestPrevious(/* char* par */)
     delete c2;
 
     // Now try both
-    RuleBasedCollator *c3 = NULL;
+    RuleBasedCollator *c3 = nullptr;
     c3 = new RuleBasedCollator((UnicodeString)"&a < b < c/aba < d < z < ch", status);
 
-    if (c3 == NULL || U_FAILURE(status))
+    if (c3 == nullptr || U_FAILURE(status))
     {
         errln("Couldn't create a RuleBasedCollator with both an expanding and a contracting sequence.");
         delete c3;
@@ -148,7 +150,7 @@ void CollationIteratorTest::TestPrevious(/* char* par */)
     if(U_FAILURE(status)){
         errln("Couldn't create a collator");
     }
-    iter = ((RuleBasedCollator*)c4)->createCollationElementIterator(source);
+    iter = (dynamic_cast<RuleBasedCollator*>(c4))->createCollationElementIterator(source);
     backAndForth(*iter);
     delete iter;
     delete c4;
@@ -156,7 +158,7 @@ void CollationIteratorTest::TestPrevious(/* char* par */)
     source= CharsToUnicodeString("\\u0061\\u30CF\\u3099\\u30FC");
     Collator *c5 = Collator::createInstance(Locale("ja", "JP", ""), status);
 
-    iter = ((RuleBasedCollator*)c5)->createCollationElementIterator(source);
+    iter = (dynamic_cast<RuleBasedCollator*>(c5))->createCollationElementIterator(source);
     if(U_FAILURE(status)){
         errln("Couldn't create Japanese collator\n");
     }
@@ -311,7 +313,7 @@ void CollationIteratorTest::TestSetText(/* char* par */)
         assertEqual(*iter1, *iter2);
     }
     iter1->reset();
-    //now use the overloaded setText(ChracterIterator&, UErrorCode) function to set the text
+    //now use the overloaded setText(CharacterIterator&, UErrorCode) function to set the text
     CharacterIterator* chariter = new StringCharacterIterator(test1);
     iter2->setText(*chariter, status);
     if (U_FAILURE(status))
@@ -330,7 +332,7 @@ void CollationIteratorTest::TestSetText(/* char* par */)
         || iter1->next(status) != (int32_t)CollationElementIterator::NULLORDER) {
         errln("Empty string should have no CEs.");
     }
-    ((StringCharacterIterator *)chariter)->setText(empty);
+    (dynamic_cast<StringCharacterIterator*>(chariter))->setText(empty);
     iter1->setText(*chariter, status);
     if (U_FAILURE(status) 
         || iter1->next(status) != (int32_t)CollationElementIterator::NULLORDER) {
@@ -349,7 +351,7 @@ void CollationIteratorTest::TestMaxExpansion(/* char* par */)
     UErrorCode          status = U_ZERO_ERROR; 
     UnicodeString rule("&a < ab < c/aba < d < z < ch");
     RuleBasedCollator  *coll   = new RuleBasedCollator(rule, status);
-    UChar               ch     = 0;
+    char16_t            ch     = 0;
     UnicodeString       str(ch);
 
     CollationElementIterator *iter   = coll->createCollationElementIterator(str);
@@ -390,7 +392,7 @@ void CollationIteratorTest::TestClearBuffers(/* char* par */)
     UErrorCode status = U_ZERO_ERROR;
     RuleBasedCollator *c = new RuleBasedCollator((UnicodeString)"&a < b < c & ab = d", status);
 
-    if (c == NULL || U_FAILURE(status))
+    if (c == nullptr || U_FAILURE(status))
     {
         errln("Couldn't create a RuleBasedCollator.");
         delete c;
@@ -457,9 +459,9 @@ void CollationIteratorTest::TestAssignment()
 {
     UErrorCode status = U_ZERO_ERROR;
     RuleBasedCollator *coll = 
-        (RuleBasedCollator *)Collator::createInstance(status);
+        dynamic_cast<RuleBasedCollator*>(Collator::createInstance(status));
 
-    if (coll == NULL || U_FAILURE(status))
+    if (coll == nullptr || U_FAILURE(status))
     {
         errln("Couldn't create a default collator.");
         return;
@@ -486,22 +488,23 @@ void CollationIteratorTest::TestAssignment()
     CollationElementIterator *iter4 
                         = coll->createCollationElementIterator(source);
     CollationElementIterator iter5(*iter4);
+    int32_t order4, order5;
     if (*iter4 != iter5) {
         errln("collation iterator assignment does not produce the same elements");
     }
-    iter4->next(status);
+    order4 = iter4->next(status);
     if (U_FAILURE(status) || *iter4 == iter5) {
         errln("collation iterator not equal");
     }
-    iter5.next(status);
+    order5 = iter5.next(status);
     if (U_FAILURE(status) || *iter4 != iter5) {
         errln("collation iterator equal");
     }
-    iter4->next(status);
+    order4 = iter4->next(status);
     if (U_FAILURE(status) || *iter4 == iter5) {
         errln("collation iterator not equal");
     }
-    iter5.next(status);
+    order5 = iter5.next(status);
     if (U_FAILURE(status) || *iter4 != iter5) {
         errln("collation iterator equal");
     }
@@ -509,21 +512,24 @@ void CollationIteratorTest::TestAssignment()
     if (*iter4 != iter6) {
         errln("collation iterator equal");
     }
-    iter4->next(status);
+    order4 = iter4->next(status);
     if (U_FAILURE(status) || *iter4 == iter5) {
         errln("collation iterator not equal");
     }
-    iter5.next(status);
+    order5 = iter5.next(status);
     if (U_FAILURE(status) || *iter4 != iter5) {
         errln("collation iterator equal");
     }
-    iter4->next(status);
-    if (U_FAILURE(status) || *iter4 == iter5) {
-        errln("collation iterator not equal");
-    }
-    iter5.next(status);
-    if (U_FAILURE(status) || *iter4 != iter5) {
-        errln("collation iterator equal");
+    if (!(order4 == CollationElementIterator::NULLORDER &&
+          order5 == CollationElementIterator::NULLORDER)) {
+        order4 = iter4->next(status);
+        if (U_FAILURE(status) || *iter4 == iter5) {
+            errln("collation iterator not equal");
+        }
+        order5 = iter5.next(status);
+        if (U_FAILURE(status) || *iter4 != iter5) {
+            errln("collation iterator equal");
+        }
     }
     delete iter1;
     delete iter4;
@@ -537,8 +543,8 @@ void CollationIteratorTest::TestConstructors()
 {
     UErrorCode status = U_ZERO_ERROR;
     RuleBasedCollator *coll = 
-        (RuleBasedCollator *)Collator::createInstance(status);
-    if (coll == NULL || U_FAILURE(status))
+        dynamic_cast<RuleBasedCollator*>(Collator::createInstance(status));
+    if (coll == nullptr || U_FAILURE(status))
     {
         errln("Couldn't create a default collator.");
         return;
@@ -594,8 +600,8 @@ void CollationIteratorTest::TestStrengthOrder()
 
     UErrorCode status = U_ZERO_ERROR;
     RuleBasedCollator *coll = 
-        (RuleBasedCollator *)Collator::createInstance(status);
-    if (coll == NULL || U_FAILURE(status))
+        dynamic_cast<RuleBasedCollator*>(Collator::createInstance(status));
+    if (coll == nullptr || U_FAILURE(status))
     {
         errln("Couldn't create a default collator.");
         return;
@@ -605,7 +611,7 @@ void CollationIteratorTest::TestStrengthOrder()
     CollationElementIterator *iter = 
         coll->createCollationElementIterator(test1);
 
-    if (iter == NULL) {
+    if (iter == nullptr) {
         errln("Couldn't create a collation element iterator from default collator");
         return;
     }
