@@ -95,6 +95,7 @@ void IntlTestSpoof::runIndexedTest( int32_t index, UBool exec, const char* &name
     TESTCASE_AUTO_BEGIN;
     TESTCASE_AUTO(testSpoofAPI);
     TESTCASE_AUTO(testSkeleton);
+    TESTCASE_AUTO(testBidiSkeleton);
     TESTCASE_AUTO(testAreConfusable);
     TESTCASE_AUTO(testInvisible);
     TESTCASE_AUTO(testConfData);
@@ -140,12 +141,27 @@ void IntlTestSpoof::testSpoofAPI() {
         TEST_ASSERT(UnicodeString("lllOO") == dest);
         TEST_ASSERT(&dest == &retStr);
     TEST_TEARDOWN;
+
+    TEST_SETUP
+        // Example from UTS #55, Section 5.1.3 https://www.unicode.org/reports/tr55/#General-Security-Profile
+        // of a minimal pair with a ZWNJ in Persian.
+        const UnicodeString behrooz(u"بهروز");
+        const UnicodeString update(u"به‌روز");
+        // These strings differ only by a ZWNJ.
+        TEST_ASSERT(UnicodeString(update).findAndReplace(u"\u200C", u"") == behrooz);
+        int32_t checkResults = uspoof_areConfusableUnicodeString(sc, behrooz, update, &status);
+        TEST_ASSERT_SUCCESS(status);
+        TEST_ASSERT_EQ(USPOOF_SINGLE_SCRIPT_CONFUSABLE, checkResults);
+    TEST_TEARDOWN;
 }
 
+#define CHECK_SKELETON(type, input, expected)                                                           \
+    UPRV_BLOCK_MACRO_BEGIN { checkSkeleton(sc, type, input, expected, __LINE__); }                      \
+    UPRV_BLOCK_MACRO_END
 
-#define CHECK_SKELETON(type, input, expected) UPRV_BLOCK_MACRO_BEGIN { \
-    checkSkeleton(sc, type, input, expected, __LINE__); \
-} UPRV_BLOCK_MACRO_END
+#define CHECK_BIDI_SKELETON(type, input, expected)                                                           \
+    UPRV_BLOCK_MACRO_BEGIN { checkBidiSkeleton(sc, type, input, expected, __LINE__); }                      \
+    UPRV_BLOCK_MACRO_END
 
 
 // testSkeleton.   Spot check a number of confusable skeleton substitutions from the 
@@ -215,6 +231,15 @@ void IntlTestSpoof::testSkeleton() {
     TEST_TEARDOWN;
 }
 
+void IntlTestSpoof::testBidiSkeleton() {
+    TEST_SETUP
+    CHECK_BIDI_SKELETON(u"A1<שׂ", UBIDI_LTR, u"Al<ש\u0307");
+    CHECK_BIDI_SKELETON(u"Αשֺ>1", UBIDI_LTR, u"Al<ש\u0307");
+    CHECK_BIDI_SKELETON(u"A1<שׂ", UBIDI_RTL, u"ש\u0307>Al");
+    CHECK_BIDI_SKELETON(u"Αשֺ>1", UBIDI_RTL, u"l<ש\u0307A");
+    TEST_TEARDOWN;
+}
+
 
 //
 //  Run a single confusable skeleton transformation test case.
@@ -240,6 +265,31 @@ void IntlTestSpoof::checkSkeleton(const USpoofChecker *sc, uint32_t type,
     }
 }
 
+//
+//  Run a single confusable bidiSkeleton transformation test case.
+//
+void IntlTestSpoof::checkBidiSkeleton(const USpoofChecker *sc, const UnicodeString &input,
+                                      UBiDiDirection direction, const UnicodeString &expected,
+                                      int32_t lineNum) {
+    UnicodeString uInput = input.unescape();
+    UnicodeString uExpected = expected.unescape();
+
+    UErrorCode status = U_ZERO_ERROR;
+    UnicodeString actual;
+    uspoof_getBidiSkeletonUnicodeString(sc, direction, uInput, actual, &status);
+    if (U_FAILURE(status)) {
+        errln("File %s, Line %d, Test case from line %d, status is %s", __FILE__, __LINE__, lineNum,
+              u_errorName(status));
+        return;
+    }
+    if (uExpected != actual) {
+        errln("File %s, Line %d, Test case from line %d, Actual and Expected skeletons differ.",
+              __FILE__, __LINE__, lineNum);
+        errln(UnicodeString(" Actual   Skeleton: \"") + actual + UnicodeString("\"\n") +
+              UnicodeString(" Expected Skeleton: \"") + uExpected + UnicodeString("\""));
+    }
+}
+
 void IntlTestSpoof::testAreConfusable() {
     TEST_SETUP
         UnicodeString s1("A long string that will overflow stack buffers.  A long string that will overflow stack buffers. "
@@ -253,6 +303,20 @@ void IntlTestSpoof::testAreConfusable() {
     TEST_TEARDOWN;
 }
 
+void IntlTestSpoof::testAreBidiConfusable() {
+    TEST_SETUP
+        const UnicodeString jHyphen2(u"J-2");
+        // The following string has RLMs around the 2–, flipping it; it uses an
+        // EN DASH instead of the HYPHEN-MINUS above.
+        const UnicodeString j2Dash(u"J\u200F2\u2013\u200F");
+        TEST_ASSERT(j2Dash == u"J‏2–‏");
+        int32_t result = uspoof_areBidiConfusableUnicodeString(sc, UBIDI_LTR, jHyphen2, j2Dash, &status);
+        TEST_ASSERT_SUCCESS(status);
+        TEST_ASSERT_EQ(USPOOF_SINGLE_SCRIPT_CONFUSABLE, result);
+
+    TEST_TEARDOWN;
+}
+
 void IntlTestSpoof::testInvisible() {
     TEST_SETUP
         UnicodeString  s = UnicodeString("abcd\\u0301ef").unescape();
@@ -384,6 +448,13 @@ void IntlTestSpoof::testConfData() {
             continue;
         }
 
+        if (u_hasBinaryProperty(from.char32At(0), UCHAR_DEFAULT_IGNORABLE_CODE_POINT)) {
+            // The source character is a default ignorable code point.
+            // Skip this case; the second step in obtaining a skeleton is to remove DIs,
+            // so the mapping in this line of confusables.txt will never be applied.
+            continue;
+        }
+
         UnicodeString rawExpected = parseHex(parseLine.group(2, status));
         UnicodeString expected;
         Normalizer::decompose(rawExpected, false /*NFD*/, 0, expected, status);
