@@ -45,9 +45,11 @@ void ListFormatterTest::runIndexedTest(int32_t index, UBool exec,
     TESTCASE_AUTO(TestFieldPositionIteratorWith3ItemsPatternShift);
     TESTCASE_AUTO(TestFormattedValue);
     TESTCASE_AUTO(TestDifferentStyles);
-    TESTCASE_AUTO(TestBadStylesFail);
     TESTCASE_AUTO(TestCreateStyled);
     TESTCASE_AUTO(TestContextual);
+    TESTCASE_AUTO(TestNextPosition);
+    TESTCASE_AUTO(TestInt32Overflow);
+    TESTCASE_AUTO(Test21871);
     TESTCASE_AUTO_END;
 }
 
@@ -70,36 +72,36 @@ void ListFormatterTest::ExpectPositions(
     ConstrainedFieldPosition cfp;
     cfp.constrainCategory(UFIELD_CATEGORY_LIST);
     if (tupleCount > 10) {
-      assertTrue("internal error, tupleCount too large", FALSE);
+      assertTrue("internal error, tupleCount too large", false);
     } else {
         for (int i = 0; i < tupleCount; ++i) {
-            found[i] = FALSE;
+            found[i] = false;
         }
     }
     while (iter.nextPosition(cfp, status)) {
-        UBool ok = FALSE;
+        UBool ok = false;
         int32_t id = cfp.getField();
         int32_t start = cfp.getStart();
         int32_t limit = cfp.getLimit();
         char buf[128];
-        sprintf(buf, "%24s %3d %3d %3d", attrString(id), id, start, limit);
+        snprintf(buf, sizeof(buf), "%24s %3d %3d %3d", attrString(id), id, start, limit);
         logln(buf);
         for (int i = 0; i < tupleCount; ++i) {
             if (found[i]) {
                 continue;
             }
             if (values[i*3] == id && values[i*3+1] == start && values[i*3+2] == limit) {
-                found[i] = ok = TRUE;
+                found[i] = ok = true;
                 break;
             }
         }
         assertTrue((UnicodeString)"found [" + attrString(id) + "," + start + "," + limit + "]", ok);
     }
     // check that all were found
-    UBool ok = TRUE;
+    UBool ok = true;
     for (int i = 0; i < tupleCount; ++i) {
         if (!found[i]) {
-            ok = FALSE;
+            ok = false;
             assertTrue((UnicodeString) "missing [" + attrString(values[i*3]) + "," + values[i*3+1] +
                        "," + values[i*3+2] + "]", found[i]);
         }
@@ -151,7 +153,7 @@ UBool ListFormatterTest::RecordFourCases(const Locale& locale, UnicodeString one
     LocalPointer<ListFormatter> formatter(ListFormatter::createInstance(locale, errorCode));
     if (U_FAILURE(errorCode)) {
         dataerrln("ListFormatter::createInstance(\"%s\", errorCode) failed in RecordFourCases: %s", locale.getName(), u_errorName(errorCode));
-        return FALSE;
+        return false;
     }
     UnicodeString input1[] = {one};
     formatter->format(input1, 1, results[0], errorCode);
@@ -163,9 +165,9 @@ UBool ListFormatterTest::RecordFourCases(const Locale& locale, UnicodeString one
     formatter->format(input4, 4, results[3], errorCode);
     if (U_FAILURE(errorCode)) {
         errln("RecordFourCases failed: %s", u_errorName(errorCode));
-        return FALSE;
+        return false;
     }
-    return TRUE;
+    return true;
 }
 
 void ListFormatterTest::TestRoot() {
@@ -274,8 +276,11 @@ void ListFormatterTest::RunTestFieldPositionIteratorWithNItemsPatternShift(
         const char16_t *expectedFormatted,
         const char* testName) {
     IcuTestErrorCode errorCode(*this, testName);
-    LocalPointer<ListFormatter> formatter(
-        ListFormatter::createInstance(Locale("ur", "IN"), "unit-narrow", errorCode));
+    LocalPointer<ListFormatter> formatter(ListFormatter::createInstance(
+        Locale("ur", "IN"), // in CLDR 41 alpha1 the "backwards order" patterns in this and other locales were removed.
+        ULISTFMT_TYPE_UNITS,
+        ULISTFMT_WIDTH_NARROW,
+        errorCode));
     if (U_FAILURE(errorCode)) {
         dataerrln(
             "ListFormatter::createInstance(Locale(\"ur\", \"IN\"), \"unit-narrow\", errorCode) failed in "
@@ -325,21 +330,21 @@ void ListFormatterTest::TestFieldPositionIteratorWith3Items() {
 }
 
 void ListFormatterTest::TestFieldPositionIteratorWith3ItemsPatternShift() {
-    //  0         1
-    //  012345678901234
-    // "cc bbb a"
+    // Note: In CLDR 41 alpha1 the "backwards order" patterns in ur_IN (and one or two
+    // other locales) were removed, ur_IN now just inherits list patterns from ur.
+    // So this test may no longer be interesting.
     UnicodeString data[3] = {"a", "bbb", "cc"};
     int32_t expected[] = {
-        ULISTFMT_ELEMENT_FIELD, 7, 8,
-        ULISTFMT_LITERAL_FIELD, 6, 7,
+        ULISTFMT_ELEMENT_FIELD, 0, 1,
+        ULISTFMT_LITERAL_FIELD, 1, 3,
         ULISTFMT_ELEMENT_FIELD, 3, 6,
-        ULISTFMT_LITERAL_FIELD, 2, 3,
-        ULISTFMT_ELEMENT_FIELD, 0, 2
+        ULISTFMT_LITERAL_FIELD, 6, 12,
+        ULISTFMT_ELEMENT_FIELD, 12, 14
     };
     int32_t tupleCount = sizeof(expected)/(3 * sizeof(*expected));
     RunTestFieldPositionIteratorWithNItemsPatternShift(
         data, 3, expected, tupleCount,
-        u"cc bbb a",
+        u"a، bbb، اور cc",
         "TestFieldPositionIteratorWith3ItemsPatternShift");
 }
 
@@ -361,19 +366,19 @@ void ListFormatterTest::TestFieldPositionIteratorWith2Items() {
 }
 
 void ListFormatterTest::TestFieldPositionIteratorWith2ItemsPatternShift() {
-    //  0         1
-    //  01234567890
-    // "cc bbb"
+    // Note: In CLDR 41 alpha1 the "backwards order" patterns in ur_IN (and one or two
+    // other locales) were removed, ur_IN now just inherits list patterns from ur.
+    // So this test may no longer be interesting.
     UnicodeString data[2] = {"bbb", "cc"};
     int32_t expected[] = {
-        ULISTFMT_ELEMENT_FIELD, 3, 6,
-        ULISTFMT_LITERAL_FIELD, 2, 3,
-        ULISTFMT_ELEMENT_FIELD, 0, 2
+        ULISTFMT_ELEMENT_FIELD, 0, 3,
+        ULISTFMT_LITERAL_FIELD, 3, 8,
+        ULISTFMT_ELEMENT_FIELD, 8, 10
     };
     int32_t tupleCount = sizeof(expected)/(3 * sizeof(*expected));
     RunTestFieldPositionIteratorWithNItemsPatternShift(
         data, 2, expected, tupleCount,
-        u"cc bbb",
+        u"bbb اور cc",
         "TestFieldPositionIteratorWith2ItemsPatternShift");
 }
 
@@ -494,10 +499,10 @@ void ListFormatterTest::TestOutOfOrderPatterns() {
 
 void ListFormatterTest::TestFormattedValue() {
     IcuTestErrorCode status(*this, "TestFormattedValue");
-    LocalPointer<ListFormatter> fmt(ListFormatter::createInstance("en", status));
-    if (status.errIfFailureAndReset()) { return; }
 
     {
+        LocalPointer<ListFormatter> fmt(ListFormatter::createInstance("en", status));
+        if (status.errIfFailureAndReset()) { return; }
         const char16_t* message = u"Field position test 1";
         const char16_t* expectedString = u"hello, wonderful, and world";
         const UnicodeString inputs[] = {
@@ -523,18 +528,105 @@ void ListFormatterTest::TestFormattedValue() {
             expectedFieldPositions,
             UPRV_LENGTHOF(expectedFieldPositions));
     }
+
+    {
+        LocalPointer<ListFormatter> fmt(ListFormatter::createInstance("zh", ULISTFMT_TYPE_UNITS, ULISTFMT_WIDTH_SHORT, status));
+        if (status.errIfFailureAndReset()) { return; }
+        const char16_t* message = u"Field position test 2 (ICU-21340)";
+        const char16_t* expectedString = u"aabbbbbbbccc";
+        const UnicodeString inputs[] = {
+            u"aa",
+            u"bbbbbbb",
+            u"ccc"
+        };
+        FormattedList result = fmt->formatStringsToValue(inputs, UPRV_LENGTHOF(inputs), status);
+        static const UFieldPositionWithCategory expectedFieldPositions[] = {
+            // field, begin index, end index
+            {UFIELD_CATEGORY_LIST_SPAN, 0, 0, 2},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_ELEMENT_FIELD, 0, 2},
+            {UFIELD_CATEGORY_LIST_SPAN, 1, 2, 9},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_ELEMENT_FIELD, 2, 9},
+            {UFIELD_CATEGORY_LIST_SPAN, 2, 9, 12},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_ELEMENT_FIELD, 9, 12}};
+        checkMixedFormattedValue(
+            message,
+            result,
+            expectedString,
+            expectedFieldPositions,
+            UPRV_LENGTHOF(expectedFieldPositions));
+    }
+
+    {
+        LocalPointer<ListFormatter> fmt(ListFormatter::createInstance("en", ULISTFMT_TYPE_UNITS, ULISTFMT_WIDTH_SHORT, status));
+        if (status.errIfFailureAndReset()) { return; }
+        const char16_t* message = u"ICU-21383 Long list";
+        const char16_t* expectedString = u"a, b, c, d, e, f, g, h, i";
+        const UnicodeString inputs[] = {
+            u"a",
+            u"b",
+            u"c",
+            u"d",
+            u"e",
+            u"f",
+            u"g",
+            u"h",
+            u"i",
+        };
+        FormattedList result = fmt->formatStringsToValue(inputs, UPRV_LENGTHOF(inputs), status);
+        static const UFieldPositionWithCategory expectedFieldPositions[] = {
+            // field, begin index, end index
+            {UFIELD_CATEGORY_LIST_SPAN, 0, 0, 1},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_ELEMENT_FIELD, 0, 1},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_LITERAL_FIELD, 1, 3},
+            {UFIELD_CATEGORY_LIST_SPAN, 1, 3, 4},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_ELEMENT_FIELD, 3, 4},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_LITERAL_FIELD, 4, 6},
+            {UFIELD_CATEGORY_LIST_SPAN, 2, 6, 7},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_ELEMENT_FIELD, 6, 7},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_LITERAL_FIELD, 7, 9},
+            {UFIELD_CATEGORY_LIST_SPAN, 3, 9, 10},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_ELEMENT_FIELD, 9, 10},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_LITERAL_FIELD, 10, 12},
+            {UFIELD_CATEGORY_LIST_SPAN, 4, 12, 13},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_ELEMENT_FIELD, 12, 13},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_LITERAL_FIELD, 13, 15},
+            {UFIELD_CATEGORY_LIST_SPAN, 5, 15, 16},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_ELEMENT_FIELD, 15, 16},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_LITERAL_FIELD, 16, 18},
+            {UFIELD_CATEGORY_LIST_SPAN, 6, 18, 19},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_ELEMENT_FIELD, 18, 19},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_LITERAL_FIELD, 19, 21},
+            {UFIELD_CATEGORY_LIST_SPAN, 7, 21, 22},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_ELEMENT_FIELD, 21, 22},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_LITERAL_FIELD, 22, 24},
+            {UFIELD_CATEGORY_LIST_SPAN, 8, 24, 25},
+            {UFIELD_CATEGORY_LIST, ULISTFMT_ELEMENT_FIELD, 24, 25},
+            };
+        checkMixedFormattedValue(
+            message,
+            result,
+            expectedString,
+            expectedFieldPositions,
+            UPRV_LENGTHOF(expectedFieldPositions));
+    }
 }
 
-void ListFormatterTest::DoTheRealListStyleTesting(Locale locale,
-        UnicodeString items[], int itemCount,
-        const char* style, const char* expected, IcuTestErrorCode status) {
+void ListFormatterTest::DoTheRealListStyleTesting(
+        Locale locale,
+        UnicodeString items[],
+        int itemCount,
+        UListFormatterType type,
+        UListFormatterWidth width,
+        const char* expected,
+        IcuTestErrorCode status) {
 
     LocalPointer<ListFormatter> formatter(
-            ListFormatter::createInstance(locale, style, status));
+            ListFormatter::createInstance(locale, type, width, status));
 
     UnicodeString actualResult;
     formatter->format(items, itemCount, actualResult, status);
-    assertEquals(style, UnicodeString(expected), actualResult);
+    assertEquals(Int64ToUnicodeString(type) + "-" + Int64ToUnicodeString(width),
+        UnicodeString(expected), actualResult);
 }
 
 void ListFormatterTest::TestDifferentStyles() {
@@ -542,24 +634,11 @@ void ListFormatterTest::TestDifferentStyles() {
     UnicodeString input[4] = { u"rouge", u"jaune", u"bleu", u"vert" };
     IcuTestErrorCode status(*this, "TestDifferentStyles()");
 
-    DoTheRealListStyleTesting(locale, input, 4, "standard", "rouge, jaune, bleu et vert", status);
-    DoTheRealListStyleTesting(locale, input, 4, "or", "rouge, jaune, bleu ou vert", status);
-    DoTheRealListStyleTesting(locale, input, 4, "unit", "rouge, jaune, bleu et vert", status);
-    DoTheRealListStyleTesting(locale, input, 4, "unit-narrow", "rouge jaune bleu vert", status);
-    DoTheRealListStyleTesting(locale, input, 4, "unit-short", "rouge, jaune, bleu et vert", status);
-}
-
-void ListFormatterTest::TestBadStylesFail() {
-    Locale locale("fr");
-    const char * badStyles[4] = { "", "duration", "duration-short", "something-clearly-wrong" };
-    IcuTestErrorCode status(*this, "TestBadStylesFail()");
-
-    for (int i = 0; i < 4; ++i) {
-      LocalPointer<ListFormatter> formatter(ListFormatter::createInstance(locale, badStyles[i], status));
-      if (!status.expectErrorAndReset(U_MISSING_RESOURCE_ERROR, "style \"%s\"", badStyles[i])) {
-        // Do nothing, expectErrorAndReset already reports the error
-      }
-    }
+    DoTheRealListStyleTesting(locale, input, 4, ULISTFMT_TYPE_AND, ULISTFMT_WIDTH_WIDE, "rouge, jaune, bleu et vert", status);
+    DoTheRealListStyleTesting(locale, input, 4, ULISTFMT_TYPE_OR, ULISTFMT_WIDTH_WIDE, "rouge, jaune, bleu ou vert", status);
+    DoTheRealListStyleTesting(locale, input, 4, ULISTFMT_TYPE_UNITS, ULISTFMT_WIDTH_WIDE, "rouge, jaune, bleu et vert", status);
+    DoTheRealListStyleTesting(locale, input, 4, ULISTFMT_TYPE_UNITS, ULISTFMT_WIDTH_NARROW, "rouge jaune bleu vert", status);
+    DoTheRealListStyleTesting(locale, input, 4, ULISTFMT_TYPE_UNITS, ULISTFMT_WIDTH_SHORT, "rouge, jaune, bleu et vert", status);
 }
 
 void ListFormatterTest::TestCreateStyled() {
@@ -700,4 +779,92 @@ void ListFormatterTest::TestContextual() {
     }
 }
 
+void ListFormatterTest::TestNextPosition() {
+    IcuTestErrorCode status(*this, "TestNextPosition");
+    std::vector<std::string> locales = { "en", "es", "zh", "ja" };
+    UListFormatterWidth widths [] = {
+        ULISTFMT_WIDTH_WIDE, ULISTFMT_WIDTH_SHORT, ULISTFMT_WIDTH_NARROW
+    };
+    const char* widthStr [] = {"wide", "short", "narrow"};
+    UListFormatterType types [] = {
+        ULISTFMT_TYPE_AND, ULISTFMT_TYPE_OR, ULISTFMT_TYPE_UNITS
+    };
+    const char* typeStr [] = {"and", "or", "units"};
+    const UnicodeString inputs[] = { u"A1", u"B2", u"C3", u"D4" };
+    for (auto width : widths) {
+        for (auto type : types) {
+            for (auto locale : locales) {
+                LocalPointer<ListFormatter> fmt(
+                        ListFormatter::createInstance(locale.c_str(), type, width, status),
+                    status);
+                if (status.errIfFailureAndReset()) {
+                    continue;
+                }
+                for (int32_t n = 1; n <= UPRV_LENGTHOF(inputs); n++) {
+                    FormattedList result = fmt->formatStringsToValue(
+                        inputs, n, status);
+                    int32_t elements = 0;
+                    icu::ConstrainedFieldPosition cfpos;
+                    cfpos.constrainCategory(UFIELD_CATEGORY_LIST);
+                    while (result.nextPosition(cfpos, status) && U_SUCCESS(status)) {
+                        if (cfpos.getField() == ULISTFMT_ELEMENT_FIELD) {
+                            elements++;
+                        }
+                    }
+                    std::string msg = locale;
+                    // Test that if there are n elements (n=1..4) in the input, then the
+                    // nextPosition() should iterate through exactly n times
+                    // with field == ULISTFMT_ELEMENT_FIELD.
+                    assertEquals((msg
+                                  .append(" w=").append(widthStr[width])
+                                  .append(" t=").append(typeStr[type])).c_str(),
+                                 n, elements);
+                }
+            }
+        }
+    }
+}
+
+void ListFormatterTest::TestInt32Overflow() {
+    if (quick) {
+        return;
+    }
+    IcuTestErrorCode status(*this, "TestInt32Overflow");
+    LocalPointer<ListFormatter> fmt(ListFormatter::createInstance("en", status), status);
+    std::vector<UnicodeString> inputs;
+    UnicodeString input(0xAAAFF00, 0x00000042, 0xAAAFF00);
+    for (int32_t i = 0; i < 16; i++) {
+      inputs.push_back(input);
+    }
+    FormattedList result = fmt->formatStringsToValue(
+        inputs.data(), static_cast<int32_t>(inputs.size()), status);
+    status.expectErrorAndReset(U_INPUT_TOO_LONG_ERROR);
+}
+
+
+void ListFormatterTest::Test21871() {
+    IcuTestErrorCode status(*this, "Test21871");
+    LocalPointer<ListFormatter> fmt(ListFormatter::createInstance("en", status), status);
+    {
+        UnicodeString strings[] = {{u"A"}, {u""}};
+        FormattedList result = fmt->formatStringsToValue(strings, 2, status);
+        ConstrainedFieldPosition cfp;
+        cfp.constrainField(UFIELD_CATEGORY_LIST, ULISTFMT_ELEMENT_FIELD);
+        assertTrue("nextPosition 1", result.nextPosition(cfp, status));
+        assertEquals("start", cfp.getStart(), 0);
+        assertEquals("limit", cfp.getLimit(), 1);
+        assertFalse("nextPosition 2", result.nextPosition(cfp, status));
+    }
+    {
+        UnicodeString strings[] = {{u""}, {u"B"}};
+        FormattedList result = fmt->formatStringsToValue(strings, 2, status);
+        ConstrainedFieldPosition cfp;
+        cfp.constrainField(UFIELD_CATEGORY_LIST, ULISTFMT_ELEMENT_FIELD);
+        assertTrue("nextPosition 1", result.nextPosition(cfp, status));
+        assertEquals("start", cfp.getStart(), 5);
+        assertEquals("limit", cfp.getLimit(), 6);
+        assertFalse("nextPosition 2", result.nextPosition(cfp, status));
+    }
+}
+
 #endif /* #if !UCONFIG_NO_FORMATTING */
