@@ -20,7 +20,7 @@
  *  This test executes basic functionality checks of various API functions
  **/
 class IntlTestNumberFormatAPI: public IntlTest {
-    void runIndexedTest( int32_t index, UBool exec, const char* &name, char* par = NULL ) override;
+    void runIndexedTest( int32_t index, UBool exec, const char* &name, char* par = nullptr ) override;
 
 private:
     /**
