@@ -1,4 +1,4 @@
-// Copyright (C) 2016 and later: Unicode, Inc. and others.
+// © 2016 and later: Unicode, Inc. and others.
 // License & terms of use: http://www.unicode.org/copyright.html
 /****************************************************************************
  * COPYRIGHT: 
@@ -28,7 +28,7 @@ public:
     virtual ~StringSearchTest();
 
     void runIndexedTest(int32_t index, UBool exec, const char* &name, 
-                        char* par = NULL);
+                        char* par = nullptr) override;
 #if !UCONFIG_NO_BREAK_ITERATION
 private:
     RuleBasedCollator *m_en_us_; 
