@@ -1,6 +1,8 @@
+// © 2016 and later: Unicode, Inc. and others.
+// License & terms of use: http://www.unicode.org/copyright.html
 /*
  *******************************************************************************
- * Copyright (C) 2003-2014, International Business Machines Corporation and
+ * Copyright (C) 2003-2016, International Business Machines Corporation and
  * others. All Rights Reserved.
  *******************************************************************************
  */
@@ -12,6 +14,7 @@
 #include "svccoll.h"
 #include "unicode/coll.h"
 #include "unicode/strenum.h"
+#include "cmemory.h"
 #include "hash.h"
 #include "uassert.h"
 
@@ -51,7 +54,7 @@ void CollationServiceTest::TestRegister()
         Collator *clone = frcol->clone();
         URegistryKey key = Collator::registerInstance(frcol, US, status);
         // frcol has been adopted. We must not use it any more, nor rely on its attributes.
-        frcol = NULL;
+        frcol = nullptr;
 
         Collator* ncol = Collator::createInstance(US_FOO, status);
         if (*clone != *ncol) {
@@ -74,7 +77,7 @@ void CollationServiceTest::TestRegister()
         if (loc != US) {
             errln(UnicodeString("actual locale for en_US_FOO is not en_US but ") + loc.getName());
         }
-        delete ncol; ncol = NULL;
+        delete ncol; ncol = nullptr;
 
         if (!Collator::unregister(key, status)) {
             errln("failed to unregister french collator");
@@ -84,7 +87,7 @@ void CollationServiceTest::TestRegister()
         if (*uscol != *ncol) {
             errln("collator after unregister does not match original");
         }
-        delete ncol; ncol = NULL;
+        delete ncol; ncol = nullptr;
     }
 
     // recreate frcol
@@ -99,7 +102,7 @@ void CollationServiceTest::TestRegister()
         Collator* fucol = Collator::createInstance(fu_FU, status);
         Collator *clone = frcol->clone();
         URegistryKey key = Collator::registerInstance(frcol, fu_FU, status);
-        frcol = NULL;  // frcol has been adopted.
+        frcol = nullptr;  // frcol has been adopted.
         Collator* ncol = Collator::createInstance(fu_FU_FOO, status);
         if (*clone != *ncol) {
             errln("register of fr collator for fu_FU failed");
@@ -108,25 +111,25 @@ void CollationServiceTest::TestRegister()
 
         UnicodeString locName = fu_FU.getName();
         StringEnumeration* localeEnum = Collator::getAvailableLocales();
-        UBool found = FALSE;
+        UBool found = false;
         const UnicodeString* locStr, *ls2;
         for (locStr = localeEnum->snext(status);
-        !found && locStr != NULL;
+        !found && locStr != nullptr;
         locStr = localeEnum->snext(status)) {
             //
             if (locName == *locStr) {
-                found = TRUE;
+                found = true;
             }
         }
 
-        StringEnumeration *le2 = NULL;
+        StringEnumeration *le2 = nullptr;
         localeEnum->reset(status);
         int32_t i, count;
         count = localeEnum->count(status);
         for(i = 0; i < count; ++i) {
             if(i == count / 2) {
                 le2 = localeEnum->clone();
-                if(le2 == NULL || count != le2->count(status)) {
+                if(le2 == nullptr || count != le2->count(status)) {
                     errln("ServiceEnumeration.clone() failed");
                     break;
                 }
@@ -152,7 +155,7 @@ void CollationServiceTest::TestRegister()
         UnicodeString displayName;
         Collator::getDisplayName(fu_FU, displayName);
         /* The locale display pattern for the locale ja, ko, and zh are different. */
-        const UChar zh_fuFU_Array[] = { 0x0066, 0x0075, 0xff08, 0x0046, 0x0055, 0xff09, 0 };
+        const char16_t zh_fuFU_Array[] = { 0x0066, 0x0075, 0xff08, 0x0046, 0x0055, 0xff09, 0 };
         const UnicodeString zh_fuFU(zh_fuFU_Array);
         const Locale& defaultLocale = Locale::getDefault();
         if (displayName != "fu (FU)" &&
@@ -189,7 +192,7 @@ void CollationServiceTest::TestRegister()
         if (nloc != fu_FU) {
             errln(UnicodeString("asked for nloc valid locale after close and got") + nloc.getName());
         }
-        delete ncol; ncol = NULL;
+        delete ncol; ncol = nullptr;
 
         if (fufu.isValid()) {
             const char* nlocstr = ucol_getLocaleByType(fufu.getAlias(), ULOC_VALID_LOCALE, &status);
@@ -202,9 +205,9 @@ void CollationServiceTest::TestRegister()
         if (*fucol != *ncol) {
             errln("collator after unregister does not match original fu_FU");
         }
-        delete uscol; uscol = NULL;
-        delete ncol; ncol = NULL;
-        delete fucol; fucol = NULL;
+        delete uscol; uscol = nullptr;
+        delete ncol; ncol = nullptr;
+        delete fucol; fucol = nullptr;
     }
 #endif
 }
@@ -238,7 +241,7 @@ CollatorInfo::~CollatorInfo() {
 UnicodeString&
 CollatorInfo::getDisplayName(const Locale& displayLocale, UnicodeString& name) const {
   if (displayNames) {
-    UnicodeString* val = (UnicodeString*)displayNames->get(displayLocale.getName());
+    UnicodeString* val = static_cast<UnicodeString*>(displayNames->get(displayLocale.getName()));
     if (val) {
       name = *val;
       return name;
@@ -261,14 +264,14 @@ class TestFactory : public CollatorFactory {
         return *p;
       }
     }
-    return NULL;
+    return nullptr;
   }
 
 public:
   TestFactory(CollatorInfo** _info)
     : info(_info)
     , count(0)
-    , ids(NULL)
+    , ids(nullptr)
   {
     CollatorInfo** p;
     for (p = info; *p; ++p) {}
@@ -283,17 +286,17 @@ public:
     delete[] ids;
   }
 
-  virtual Collator* createCollator(const Locale& loc) {
+  virtual Collator* createCollator(const Locale& loc) override {
     const CollatorInfo* ci = getInfo(loc);
     if (ci) {
       return ci->collator->clone();
     }
-    return NULL;
+    return nullptr;
   }
 
   virtual UnicodeString& getDisplayName(const Locale& objectLocale,
                                         const Locale& displayLocale,
-                                        UnicodeString& result)
+                                        UnicodeString& result) override
   {
     const CollatorInfo* ci = getInfo(objectLocale);
     if (ci) {
@@ -304,14 +307,14 @@ public:
     return result;
   }
 
-  const UnicodeString* getSupportedIDs(int32_t& _count, UErrorCode& status) {
+  const UnicodeString* getSupportedIDs(int32_t& _count, UErrorCode& status) override {
     if (U_SUCCESS(status)) {
       if (!ids) {
         ids = new UnicodeString[count];
         if (!ids) {
           status = U_MEMORY_ALLOCATION_ERROR;
           _count = 0;
-          return NULL;
+          return nullptr;
         }
 
         for (int i = 0; i < count; ++i) {
@@ -322,10 +325,10 @@ public:
       _count = count;
       return ids;
     }
-    return NULL;
+    return nullptr;
   }
 
-  virtual inline UClassID getDynamicClassID() const {
+  virtual inline UClassID getDynamicClassID() const override {
     return (UClassID)&gClassID;
   }
 
@@ -340,7 +343,7 @@ private:
 char TestFactory::gClassID = 0;
 #endif
 
-void CollationServiceTest::TestRegisterFactory(void)
+void CollationServiceTest::TestRegisterFactory()
 {
 #if !UCONFIG_NO_SERVICE
     int32_t n1, n2, n3;
@@ -349,7 +352,7 @@ void CollationServiceTest::TestRegisterFactory(void)
 
     UErrorCode status = U_ZERO_ERROR;
 
-    Hashtable* fuFUNames = new Hashtable(FALSE, status);
+    Hashtable* fuFUNames = new Hashtable(false, status);
     if (!fuFUNames) {
         errln("memory allocation error");
         return;
@@ -378,10 +381,10 @@ void CollationServiceTest::TestRegisterFactory(void)
         return;
     }
 
-    info[0] = new CollatorInfo(Locale::getUS(), frcol, NULL);
-    info[1] = new CollatorInfo(Locale::getFrance(), gecol, NULL);
+    info[0] = new CollatorInfo(Locale::getUS(), frcol, nullptr);
+    info[1] = new CollatorInfo(Locale::getFrance(), gecol, nullptr);
     info[2] = new CollatorInfo(fu_FU, jpcol, fuFUNames);
-    info[3] = NULL;
+    info[3] = nullptr;
 
     TestFactory* factory = new TestFactory(info);
     if (!factory) {
@@ -404,7 +407,7 @@ void CollationServiceTest::TestRegisterFactory(void)
         if (*frcol != *ncol) {
             errln("frcoll for en_US failed");
         }
-        delete ncol; ncol = NULL;
+        delete ncol; ncol = nullptr;
 
         ncol = Collator::createInstance(fu_FU_FOO, status);
         if (*jpcol != *ncol) {
@@ -422,18 +425,18 @@ void CollationServiceTest::TestRegisterFactory(void)
         if (loc != fu_FU) {
             errln(UnicodeString("valid locale for fu_FU_FOO is not fu_FU but ") + loc.getName());
         }
-        delete ncol; ncol = NULL;
+        delete ncol; ncol = nullptr;
 
         UnicodeString locName = fu_FU.getName();
         StringEnumeration* localeEnum = Collator::getAvailableLocales();
-        UBool found = FALSE;
+        UBool found = false;
         const UnicodeString* locStr;
         for (locStr = localeEnum->snext(status);
-            !found && locStr != NULL;
+            !found && locStr != nullptr;
             locStr = localeEnum->snext(status))
         {
             if (locName == *locStr) {
-                found = TRUE;
+                found = true;
             }
         }
         delete localeEnum;
@@ -476,7 +479,7 @@ void CollationServiceTest::TestRegisterFactory(void)
 /**
  * Iterate through the given iterator, checking to see that all the strings
  * in the expected array are present.
- * @param expected array of strings we expect to see, or NULL
+ * @param expected array of strings we expect to see, or nullptr
  * @param expectedCount number of elements of expected, or 0
  */
 int32_t CollationServiceTest::checkStringEnumeration(const char* msg,
@@ -491,7 +494,7 @@ int32_t CollationServiceTest::checkStringEnumeration(const char* msg,
     int32_t seenMask = 0;
     for (;; ++i) {
         const UnicodeString* s = iter.snext(ec);
-        if (!assertSuccess("snext", ec) || s == NULL)
+        if (!assertSuccess("snext", ec) || s == nullptr)
             break;
         if (i != 0)
             buf.append(UNICODE_STRING_SIMPLE(", "));
@@ -499,7 +502,7 @@ int32_t CollationServiceTest::checkStringEnumeration(const char* msg,
         // check expected list
         for (int32_t j=0, bit=1; j<expectedCount; ++j, bit<<=1) {
             if ((seenMask&bit)==0) {
-                UnicodeString exp(expected[j], (char*)NULL);
+                UnicodeString exp(expected[j], (char*)nullptr);
                 if (*s == exp) {
                     seenMask |= bit;
                     logln((UnicodeString)"Ok: \"" + exp + "\" seen");
@@ -516,8 +519,8 @@ int32_t CollationServiceTest::checkStringEnumeration(const char* msg,
     assertTrue("count verified", i==n);
     iter.reset(ec);
     for (;; ++idxAfterReset) {
-        const UChar *s = iter.unext(NULL, ec);
-        if (!assertSuccess("unext", ec) || s == NULL)
+        const char16_t *s = iter.unext(nullptr, ec);
+        if (!assertSuccess("unext", ec) || s == nullptr)
             break;
         if (idxAfterReset != 0)
             buffAfterReset.append(UNICODE_STRING_SIMPLE(", "));
@@ -543,8 +546,8 @@ int32_t CollationServiceTest::checkStringEnumeration(const char* msg,
 #if !UCONFIG_NO_SERVICE
 int32_t CollationServiceTest::checkAvailable(const char* msg) {
     StringEnumeration *iter = Collator::getAvailableLocales();
-    if (!assertTrue("getAvailableLocales != NULL", iter!=NULL)) return -1;
-    int32_t n = checkStringEnumeration(msg, *iter, NULL, 0);
+    if (!assertTrue("getAvailableLocales != nullptr", iter!=nullptr)) return -1;
+    int32_t n = checkStringEnumeration(msg, *iter, nullptr, 0);
     delete iter;
     return n;
 }
@@ -553,24 +556,26 @@ int32_t CollationServiceTest::checkAvailable(const char* msg) {
 static const char* KW[] = {
     "collation"
 };
-static const int32_t KW_COUNT = sizeof(KW)/sizeof(KW[0]);
+static const int32_t KW_COUNT = UPRV_LENGTHOF(KW);
 
 static const char* KWVAL[] = {
     "phonebook",
-    "stroke"
+    "stroke",
+    "emoji",
+    "eor"
 };
-static const int32_t KWVAL_COUNT = sizeof(KWVAL)/sizeof(KWVAL[0]);
+static const int32_t KWVAL_COUNT = UPRV_LENGTHOF(KWVAL);
 
 void CollationServiceTest::TestSeparateTree() {
     UErrorCode ec = U_ZERO_ERROR;
     StringEnumeration *iter = Collator::getKeywords(ec);
-    if (!assertTrue("getKeywords != NULL", iter!=NULL)) return;
+    if (!assertTrue("getKeywords != nullptr", iter!=nullptr)) return;
     if (!assertSuccess("getKeywords", ec)) return;
     checkStringEnumeration("getKeywords", *iter, KW, KW_COUNT);
     delete iter;
 
     iter = Collator::getKeywordValues(KW[0], ec);
-    if (!assertTrue("getKeywordValues != NULL", iter!=NULL, FALSE, TRUE)) return;
+    if (!assertTrue("getKeywordValues != nullptr", iter!=nullptr, false, true)) return;
     if (!assertSuccess("getKeywordValues", ec)) return;
     checkStringEnumeration("getKeywordValues", *iter, KWVAL, KWVAL_COUNT);
     delete iter;
@@ -580,33 +585,33 @@ void CollationServiceTest::TestSeparateTree() {
                                                      Locale::createFromName("de"),
                                                      isAvailable, ec);
     assertSuccess("getFunctionalEquivalent", ec);
-    assertEquals("getFunctionalEquivalent(de)", "root", equiv.getName());
-    assertTrue("getFunctionalEquivalent(de).isAvailable==TRUE",
-               isAvailable == TRUE);
+    assertEquals("getFunctionalEquivalent(de)", "", equiv.getName());
+    assertTrue("getFunctionalEquivalent(de).isAvailable==true",
+               isAvailable == true);
 
     equiv = Collator::getFunctionalEquivalent("collation",
                                               Locale::createFromName("de_DE"),
                                               isAvailable, ec);
     assertSuccess("getFunctionalEquivalent", ec);
-    assertEquals("getFunctionalEquivalent(de_DE)", "root", equiv.getName());
-    assertTrue("getFunctionalEquivalent(de_DE).isAvailable==FALSE",
-               isAvailable == FALSE);
+    assertEquals("getFunctionalEquivalent(de_DE)", "", equiv.getName());
+    assertTrue("getFunctionalEquivalent(de_DE).isAvailable==false",
+               isAvailable == false);
 
     equiv = Collator::getFunctionalEquivalent("collation",
                                                      Locale::createFromName("sv"),
                                                      isAvailable, ec);
     assertSuccess("getFunctionalEquivalent", ec);
     assertEquals("getFunctionalEquivalent(sv)", "sv", equiv.getName());
-    assertTrue("getFunctionalEquivalent(sv).isAvailable==TRUE",
-               isAvailable == TRUE);
+    assertTrue("getFunctionalEquivalent(sv).isAvailable==true",
+               isAvailable == true);
 
     equiv = Collator::getFunctionalEquivalent("collation",
                                               Locale::createFromName("sv_SE"),
                                               isAvailable, ec);
     assertSuccess("getFunctionalEquivalent", ec);
     assertEquals("getFunctionalEquivalent(sv_SE)", "sv", equiv.getName());
-    assertTrue("getFunctionalEquivalent(sv_SE).isAvailable==FALSE",
-               isAvailable == FALSE);
+    assertTrue("getFunctionalEquivalent(sv_SE).isAvailable==false",
+               isAvailable == false);
 }
 
 #endif
