@@ -1,8 +1,12 @@
 /*
-**********************************************************************
+***********************************************************************
+* © 2016 and later: Unicode, Inc. and others.
+* License & terms of use: http://www.unicode.org/copyright.html
+***********************************************************************
+***********************************************************************
 * Copyright (c) 2013-2014, International Business Machines
 * Corporation and others.  All Rights Reserved.
-**********************************************************************
+***********************************************************************
 */
 
 #include <string.h>
@@ -26,11 +30,11 @@ struct CompactArrays{\
     UNIT    * data; /*the real space to hold strings*/ \
     \
     ~CompactArrays(){free(index);free(data);} \
-    CompactArrays() : count(0), index(NULL), data(NULL) { \
+    CompactArrays() : count(0), index(nullptr), data(nullptr) { \
         index = (int32_t *) realloc(index, sizeof(int32_t)); \
         index[0] = 0; \
     } \
-    void append_one(int32_t theLen){ /*include terminal NULL*/ \
+    void append_one(int32_t theLen){ /*include terminal NUL*/ \
         count++; \
         index = (int32_t *) realloc(index, sizeof(int32_t) * (count + 1)); \
         index[count] = index[count - 1] + theLen; \
@@ -38,10 +42,10 @@ struct CompactArrays{\
     } \
     UNIT * last(){return data + index[count - 1];} \
     const UNIT * dataOf(int32_t i) const {return data + index[i];} \
-    int32_t lengthOf(int i) const {return index[i+1] - index[i] - 1; } /*exclude terminating NULL*/  \
+    int32_t lengthOf(int i) const {return index[i+1] - index[i] - 1; } /*exclude terminating NUL*/  \
 };
 
-COMPACT_ARRAY(CA_uchar, UChar)
+COMPACT_ARRAY(CA_uchar, char16_t)
 COMPACT_ARRAY(CA_char, char)
 
 #define MAX_TEST_STRINGS_FOR_PERMUTING 1000
@@ -742,7 +746,7 @@ long CppGetCollationKey::getOperationsPerIteration() {
 namespace {
 
 struct CollatorAndCounter {
-    CollatorAndCounter(const Collator& coll) : coll(coll), ucoll(NULL), counter(0) {}
+    CollatorAndCounter(const Collator& coll) : coll(coll), ucoll(nullptr), counter(0) {}
     CollatorAndCounter(const Collator& coll, const UCollator *ucoll)
             : coll(coll), ucoll(ucoll), counter(0) {}
     const Collator& coll;
@@ -790,7 +794,7 @@ public:
             : CollPerfFunction(coll, ucoll), d16(data16),
               source(new UnicodeString*[d16->count]) {
         for (int32_t i = 0; i < d16->count; ++i) {
-            source[i] = new UnicodeString(TRUE, d16->dataOf(i), d16->lengthOf(i));
+            source[i] = new UnicodeString(true, d16->dataOf(i), d16->lengthOf(i));
         }
     }
     virtual ~UniStrCollPerfFunction();
@@ -833,7 +837,7 @@ void UniStrSort::call(UErrorCode* status) {
     int32_t count = d16->count;
     memcpy(dest, source, count * sizeof(UnicodeString *));
     uprv_sortArray(dest, count, (int32_t)sizeof(UnicodeString *),
-                   UniStrCollatorComparator, &cc, TRUE, status);
+                   UniStrCollatorComparator, &cc, true, status);
     ops = cc.counter;
 }
 
@@ -918,7 +922,7 @@ void StringPieceSortCpp::call(UErrorCode* status) {
     int32_t count = d8->count;
     memcpy(dest, source, count * sizeof(StringPiece));
     uprv_sortArray(dest, count, (int32_t)sizeof(StringPiece),
-                   StringPieceCollatorComparator, &cc, TRUE, status);
+                   StringPieceCollatorComparator, &cc, true, status);
     ops = cc.counter;
 }
 
@@ -942,7 +946,7 @@ void StringPieceSortC::call(UErrorCode* status) {
     int32_t count = d8->count;
     memcpy(dest, source, count * sizeof(StringPiece));
     uprv_sortArray(dest, count, (int32_t)sizeof(StringPiece),
-                   StringPieceUCollatorComparator, &cc, TRUE, status);
+                   StringPieceUCollatorComparator, &cc, true, status);
     ops = cc.counter;
 }
 
@@ -1042,7 +1046,7 @@ public:
     CollPerf2Test(int32_t argc, const char *argv[], UErrorCode &status);
     ~CollPerf2Test();
     virtual UPerfFunction* runIndexedTest(
-        int32_t index, UBool exec, const char *&name, char *par = NULL);
+        int32_t index, UBool exec, const char *&name, char *par = nullptr);
 
 private:
     UCollator* coll;
@@ -1126,153 +1130,30 @@ private:
 
 CollPerf2Test::CollPerf2Test(int32_t argc, const char *argv[], UErrorCode &status) :
     UPerfTest(argc, argv, status),
-    coll(NULL),
-    collObj(NULL),
+    coll(nullptr),
+    collObj(nullptr),
     count(0),
-    data16(NULL),
-    data8(NULL),
-    modData16(NULL),
-    modData8(NULL),
-    sortedData16(NULL),
-    sortedData8(NULL),
-    randomData16(NULL),
-    randomData8(NULL)
+    data16(nullptr),
+    data8(nullptr),
+    modData16(nullptr),
+    modData8(nullptr),
+    sortedData16(nullptr),
+    sortedData8(nullptr),
+    randomData16(nullptr),
+    randomData8(nullptr)
 {
     if (U_FAILURE(status)) {
         return;
     }
 
-    if (locale == NULL){
-        locale = "en_US";   // set default locale
+    if (locale == nullptr){
+        locale = "root";
     }
 
-    //  Set up an ICU collator
+    // Set up an ICU collator.
+    // Starting with ICU 54 (ticket #8260), this supports standard collation locale keywords.
     coll = ucol_open(locale, &status);
     collObj = Collator::createInstance(locale, status);
-
-    // Keyword support should be actually a part of ICU collator, see ICU ticket #8260.
-    char keyBuffer[256];
-    UColAttributeValue val;
-    if (uloc_getKeywordValue(locale, "strength", keyBuffer, sizeof(keyBuffer)/sizeof(keyBuffer[0]), &status)) {
-        if (strcmp(keyBuffer, "primary") == 0) {
-            val = UCOL_PRIMARY;
-        } else if (strcmp(keyBuffer, "secondary") == 0) {
-            val = UCOL_SECONDARY;
-        } else if (strcmp(keyBuffer, "tertiary") == 0) {
-            val = UCOL_TERTIARY;
-        } else if (strcmp(keyBuffer, "quaternary") == 0) {
-            val = UCOL_QUATERNARY;
-        } else if (strcmp(keyBuffer, "identical") == 0) {
-            val = UCOL_IDENTICAL;
-        } else {
-            status = U_ILLEGAL_ARGUMENT_ERROR;
-        }
-        if (U_SUCCESS(status)) {
-            ucol_setAttribute(coll, UCOL_STRENGTH, val, &status);
-            collObj->setAttribute(UCOL_STRENGTH, val, status);
-        }
-    }
-    if (uloc_getKeywordValue(locale, "alternate", keyBuffer, sizeof(keyBuffer)/sizeof(keyBuffer[0]), &status)) {
-        if (strcmp(keyBuffer, "non-ignorable") == 0) {
-            val = UCOL_NON_IGNORABLE;
-        } else if (strcmp(keyBuffer, "shifted") == 0) {
-            val = UCOL_SHIFTED;
-        } else {
-            status = U_ILLEGAL_ARGUMENT_ERROR;
-        }
-        if (U_SUCCESS(status)) {
-            ucol_setAttribute(coll, UCOL_ALTERNATE_HANDLING, val, &status);
-            collObj->setAttribute(UCOL_ALTERNATE_HANDLING, val, status);
-        }
-    }
-    if (uloc_getKeywordValue(locale, "backwards", keyBuffer, sizeof(keyBuffer)/sizeof(keyBuffer[0]), &status)) {
-        if (strcmp(keyBuffer, "on") == 0) {
-            val = UCOL_ON;
-        } else if (strcmp(keyBuffer, "off") == 0) {
-            val = UCOL_OFF;
-        } else {
-            status = U_ILLEGAL_ARGUMENT_ERROR;
-        }
-        if (U_SUCCESS(status)) {
-            ucol_setAttribute(coll, UCOL_FRENCH_COLLATION, val, &status);
-            collObj->setAttribute(UCOL_FRENCH_COLLATION, val, status);
-        }
-    }
-    if (uloc_getKeywordValue(locale, "normalization", keyBuffer, sizeof(keyBuffer)/sizeof(keyBuffer[0]), &status)) {
-        if (strcmp(keyBuffer, "on") == 0) {
-            val = UCOL_ON;
-        } else if (strcmp(keyBuffer, "off") == 0) {
-            val = UCOL_OFF;
-        } else {
-            status = U_ILLEGAL_ARGUMENT_ERROR;
-        }
-        if (U_SUCCESS(status)) {
-            ucol_setAttribute(coll, UCOL_NORMALIZATION_MODE, val, &status);
-            collObj->setAttribute(UCOL_NORMALIZATION_MODE, val, status);
-        }
-    }
-    if (uloc_getKeywordValue(locale, "caseLevel", keyBuffer, sizeof(keyBuffer)/sizeof(keyBuffer[0]), &status)) {
-        if (strcmp(keyBuffer, "on") == 0) {
-            val = UCOL_ON;
-        } else if (strcmp(keyBuffer, "off") == 0) {
-            val = UCOL_OFF;
-        } else {
-            status = U_ILLEGAL_ARGUMENT_ERROR;
-        }
-        if (U_SUCCESS(status)) {
-            ucol_setAttribute(coll, UCOL_CASE_LEVEL, val, &status);
-            collObj->setAttribute(UCOL_CASE_LEVEL, val, status);
-        }
-    }
-    if (uloc_getKeywordValue(locale, "caseFirst", keyBuffer, sizeof(keyBuffer)/sizeof(keyBuffer[0]), &status)) {
-        if (strcmp(keyBuffer, "upper") == 0) {
-            val = UCOL_UPPER_FIRST;
-        } else if (strcmp(keyBuffer, "lower") == 0) {
-            val = UCOL_LOWER_FIRST;
-        } else if (strcmp(keyBuffer, "off") == 0) {
-            val = UCOL_OFF;
-        } else {
-            status = U_ILLEGAL_ARGUMENT_ERROR;
-        }
-        if (U_SUCCESS(status)) {
-            ucol_setAttribute(coll, UCOL_CASE_FIRST, val, &status);
-            collObj->setAttribute(UCOL_CASE_FIRST, val, status);
-        }
-    }
-    if (uloc_getKeywordValue(locale, "hiraganaQuaternary", keyBuffer, sizeof(keyBuffer)/sizeof(keyBuffer[0]), &status)) {
-        if (strcmp(keyBuffer, "on") == 0) {
-            val = UCOL_ON;
-        } else if (strcmp(keyBuffer, "off") == 0) {
-            val = UCOL_OFF;
-        } else {
-            status = U_ILLEGAL_ARGUMENT_ERROR;
-        }
-        if (U_SUCCESS(status)) {
-            ucol_setAttribute(coll, UCOL_HIRAGANA_QUATERNARY_MODE, val, &status);
-            collObj->setAttribute(UCOL_HIRAGANA_QUATERNARY_MODE, val, status);
-        }
-    }
-    if (uloc_getKeywordValue(locale, "numeric", keyBuffer, sizeof(keyBuffer)/sizeof(keyBuffer[0]), &status)) {
-        if (strcmp(keyBuffer, "on") == 0) {
-            val = UCOL_ON;
-        } else if (strcmp(keyBuffer, "off") == 0) {
-            val = UCOL_OFF;
-        } else {
-            status = U_ILLEGAL_ARGUMENT_ERROR;
-        }
-        if (U_SUCCESS(status)) {
-            ucol_setAttribute(coll, UCOL_NUMERIC_COLLATION, val, &status);
-            collObj->setAttribute(UCOL_NUMERIC_COLLATION, val, status);
-        }
-    }
-    if (uloc_getKeywordValue(locale, "variableTop", keyBuffer, sizeof(keyBuffer)/sizeof(keyBuffer[0]), &status)) {
-        // no support for now
-        status = U_UNSUPPORTED_ERROR;
-    }
-    if (uloc_getKeywordValue(locale, "reorder", keyBuffer, sizeof(keyBuffer)/sizeof(keyBuffer[0]), &status)) {
-        // no support for now
-        status = U_UNSUPPORTED_ERROR;
-    }
 }
 
 CollPerf2Test::~CollPerf2Test()
@@ -1294,17 +1175,17 @@ CollPerf2Test::~CollPerf2Test()
 
 const CA_uchar* CollPerf2Test::getData16(UErrorCode &status)
 {
-    if (U_FAILURE(status)) return NULL;
+    if (U_FAILURE(status)) return nullptr;
     if (data16) return data16;
 
     CA_uchar* d16 = new CA_uchar();
-    const UChar *line = NULL;
+    const char16_t *line = nullptr;
     int32_t len = 0;
     int32_t numData = 0;
 
     for (;;) {
         line = ucbuf_readline(ucharBuf, &len, &status);
-        if (line == NULL || U_FAILURE(status)) break;
+        if (line == nullptr || U_FAILURE(status)) break;
 
         // Refer to the source code of ucbuf_readline()
         // 1. 'len' includes the line terminal symbols
@@ -1315,7 +1196,9 @@ const CA_uchar* CollPerf2Test::getData16(UErrorCode &status)
             continue; // skip empty/comment line
         } else {
             d16->append_one(len);
-            u_memcpy(d16->last(), line, len);
+            char16_t *p = d16->last();
+            u_memcpy(p, line, len - 1);  // exclude the CR
+            p[len - 1] = 0;  // NUL-terminate
 
             numData++;
             if (numData >= MAX_NUM_DATA) break;
@@ -1333,36 +1216,36 @@ const CA_uchar* CollPerf2Test::getData16(UErrorCode &status)
 
 const CA_char* CollPerf2Test::getData8(UErrorCode &status)
 {
-    if (U_FAILURE(status)) return NULL;
+    if (U_FAILURE(status)) return nullptr;
     if (data8) return data8;
     return data8 = getData8FromData16(getData16(status), status);
 }
 
 const CA_uchar* CollPerf2Test::getModData16(UErrorCode &status)
 {
-    if (U_FAILURE(status)) return NULL;
+    if (U_FAILURE(status)) return nullptr;
     if (modData16) return modData16;
 
     const CA_uchar* d16 = getData16(status);
-    if (U_FAILURE(status)) return NULL;
+    if (U_FAILURE(status)) return nullptr;
 
     CA_uchar* modData16 = new CA_uchar();
 
     for (int32_t i = 0; i < d16->count; i++) {
-        const UChar *s = d16->dataOf(i);
-        int32_t len = d16->lengthOf(i) + 1; // including NULL terminator
+        const char16_t *s = d16->dataOf(i);
+        int32_t len = d16->lengthOf(i) + 1; // including NUL terminator
 
         modData16->append_one(len);
         u_memcpy(modData16->last(), s, len);
 
         // replacing the last character with a different character
-        UChar *lastChar = &modData16->last()[len -2];
+        char16_t *lastChar = &modData16->last()[len -2];
         for (int32_t j = i + 1; j != i; j++) {
             if (j >= d16->count) {
                 j = 0;
             }
-            const UChar *s1 = d16->dataOf(j);
-            UChar lastChar1 = s1[d16->lengthOf(j) - 1];
+            const char16_t *s1 = d16->dataOf(j);
+            char16_t lastChar1 = s1[d16->lengthOf(j) - 1];
             if (*lastChar != lastChar1) {
                 *lastChar = lastChar1;
                 break;
@@ -1375,7 +1258,7 @@ const CA_uchar* CollPerf2Test::getModData16(UErrorCode &status)
 
 const CA_char* CollPerf2Test::getModData8(UErrorCode &status)
 {
-    if (U_FAILURE(status)) return NULL;
+    if (U_FAILURE(status)) return nullptr;
     if (modData8) return modData8;
     return modData8 = getData8FromData16(getModData16(status), status);
 }
@@ -1413,7 +1296,7 @@ U16HashComparator(const void* context, const void* left, const void* right) {
 }  // namespace
 
 const CA_uchar* CollPerf2Test::getSortedData16(UErrorCode &status) {
-    if (U_FAILURE(status)) return NULL;
+    if (U_FAILURE(status)) return nullptr;
     if (sortedData16) return sortedData16;
 
     ArrayAndColl ac(getData16(status), *collObj);
@@ -1421,13 +1304,13 @@ const CA_uchar* CollPerf2Test::getSortedData16(UErrorCode &status) {
 }
 
 const CA_char* CollPerf2Test::getSortedData8(UErrorCode &status) {
-    if (U_FAILURE(status)) return NULL;
+    if (U_FAILURE(status)) return nullptr;
     if (sortedData8) return sortedData8;
     return sortedData8 = getData8FromData16(getSortedData16(status), status);
 }
 
 const CA_uchar* CollPerf2Test::getRandomData16(UErrorCode &status) {
-    if (U_FAILURE(status)) return NULL;
+    if (U_FAILURE(status)) return nullptr;
     if (randomData16) return randomData16;
 
     // Sort the strings by their hash codes, which should be a reasonably pseudo-random order.
@@ -1436,7 +1319,7 @@ const CA_uchar* CollPerf2Test::getRandomData16(UErrorCode &status) {
 }
 
 const CA_char* CollPerf2Test::getRandomData8(UErrorCode &status) {
-    if (U_FAILURE(status)) return NULL;
+    if (U_FAILURE(status)) return nullptr;
     if (randomData8) return randomData8;
     return randomData8 = getData8FromData16(getRandomData16(status), status);
 }
@@ -1444,21 +1327,22 @@ const CA_char* CollPerf2Test::getRandomData8(UErrorCode &status) {
 CA_uchar* CollPerf2Test::sortData16(const CA_uchar* d16,
                                     UComparator *cmp, const void *context,
                                     UErrorCode &status) {
-    if (U_FAILURE(status)) return NULL;
+    if (U_FAILURE(status)) return nullptr;
 
     LocalArray<int32_t> indexes(new int32_t[d16->count]);
     for (int32_t i = 0; i < d16->count; ++i) {
         indexes[i] = i;
     }
-    uprv_sortArray(indexes.getAlias(), d16->count, 4, cmp, context, TRUE, &status);
-    if (U_FAILURE(status)) return NULL;
+    uprv_sortArray(indexes.getAlias(), d16->count, 4, cmp, context, true, &status);
+    if (U_FAILURE(status)) return nullptr;
 
     // Copy the strings in sorted order into a new array.
     LocalPointer<CA_uchar> newD16(new CA_uchar());
     for (int32_t i = 0; i < d16->count; i++) {
-        const UChar* s = d16->dataOf(i);
-        int32_t len = d16->lengthOf(i);
-        int32_t capacity = len + 1;  // including NULL terminator
+        int32_t j = indexes[i];
+        const char16_t* s = d16->dataOf(j);
+        int32_t len = d16->lengthOf(j);
+        int32_t capacity = len + 1;  // including NUL terminator
         newD16->append_one(capacity);
         u_memcpy(newD16->last(), s, capacity);
     }
@@ -1466,44 +1350,44 @@ CA_uchar* CollPerf2Test::sortData16(const CA_uchar* d16,
     if (U_SUCCESS(status)) {
         return newD16.orphan();
     } else {
-        return NULL;
+        return nullptr;
     }
 }
 
 CA_char* CollPerf2Test::getData8FromData16(const CA_uchar* d16, UErrorCode &status) {
-    if (U_FAILURE(status)) return NULL;
+    if (U_FAILURE(status)) return nullptr;
 
     // UTF-16 -> UTF-8 conversion
     LocalPointer<CA_char> d8(new CA_char());
     for (int32_t i = 0; i < d16->count; i++) {
-        const UChar *s16 = d16->dataOf(i);
+        const char16_t *s16 = d16->dataOf(i);
         int32_t length16 = d16->lengthOf(i);
 
         // get length in UTF-8
         int32_t length8;
-        u_strToUTF8(NULL, 0, &length8, s16, length16, &status);
+        u_strToUTF8(nullptr, 0, &length8, s16, length16, &status);
         if (status == U_BUFFER_OVERFLOW_ERROR || status == U_ZERO_ERROR){
             status = U_ZERO_ERROR;
         } else {
             break;
         }
-        int32_t capacity8 = length8 + 1;  // plus terminal NULL
+        int32_t capacity8 = length8 + 1;  // plus terminal NUL
         d8->append_one(capacity8);
 
         // convert to UTF-8
-        u_strToUTF8(d8->last(), capacity8, NULL, s16, length16, &status);
+        u_strToUTF8(d8->last(), capacity8, nullptr, s16, length16, &status);
         if (U_FAILURE(status)) break;
     }
 
     if (U_SUCCESS(status)) {
         return d8.orphan();
     } else {
-        return NULL;
+        return nullptr;
     }
 }
 
 UPerfFunction*
-CollPerf2Test::runIndexedTest(int32_t index, UBool exec, const char *&name, char *par /*= NULL*/)
+CollPerf2Test::runIndexedTest(int32_t index, UBool exec, const char *&name, char *par /*= nullptr*/)
 {
     (void)par;
     TESTCASE_AUTO_BEGIN;
@@ -1551,7 +1435,7 @@ CollPerf2Test::runIndexedTest(int32_t index, UBool exec, const char *&name, char
     TESTCASE_AUTO(TestStringPieceBinSearchC);
 
     TESTCASE_AUTO_END;
-    return NULL;
+    return nullptr;
 }
 
 
@@ -1559,10 +1443,10 @@ CollPerf2Test::runIndexedTest(int32_t index, UBool exec, const char *&name, char
 UPerfFunction* CollPerf2Test::TestStrcoll()
 {
     UErrorCode status = U_ZERO_ERROR;
-    Strcoll *testCase = new Strcoll(coll, getData16(status), TRUE /* useLen */);
+    Strcoll *testCase = new Strcoll(coll, getData16(status), true /* useLen */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1570,10 +1454,10 @@ UPerfFunction* CollPerf2Test::TestStrcoll()
 UPerfFunction* CollPerf2Test::TestStrcollNull()
 {
     UErrorCode status = U_ZERO_ERROR;
-    Strcoll *testCase = new Strcoll(coll, getData16(status), FALSE /* useLen */);
+    Strcoll *testCase = new Strcoll(coll, getData16(status), false /* useLen */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1581,10 +1465,10 @@ UPerfFunction* CollPerf2Test::TestStrcollNull()
 UPerfFunction* CollPerf2Test::TestStrcollSimilar()
 {
     UErrorCode status = U_ZERO_ERROR;
-    Strcoll_2 *testCase = new Strcoll_2(coll, getData16(status), getModData16(status), TRUE /* useLen */);
+    Strcoll_2 *testCase = new Strcoll_2(coll, getData16(status), getModData16(status), true /* useLen */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1592,10 +1476,10 @@ UPerfFunction* CollPerf2Test::TestStrcollSimilar()
 UPerfFunction* CollPerf2Test::TestStrcollUTF8()
 {
     UErrorCode status = U_ZERO_ERROR;
-    StrcollUTF8 *testCase = new StrcollUTF8(coll, getData8(status), TRUE /* useLen */);
+    StrcollUTF8 *testCase = new StrcollUTF8(coll, getData8(status), true /* useLen */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1603,10 +1487,10 @@ UPerfFunction* CollPerf2Test::TestStrcollUTF8()
 UPerfFunction* CollPerf2Test::TestStrcollUTF8Null()
 {
     UErrorCode status = U_ZERO_ERROR;
-    StrcollUTF8 *testCase = new StrcollUTF8(coll, getData8(status),FALSE /* useLen */);
+    StrcollUTF8 *testCase = new StrcollUTF8(coll, getData8(status),false /* useLen */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1614,10 +1498,10 @@ UPerfFunction* CollPerf2Test::TestStrcollUTF8Null()
 UPerfFunction* CollPerf2Test::TestStrcollUTF8Similar()
 {
     UErrorCode status = U_ZERO_ERROR;
-    StrcollUTF8_2 *testCase = new StrcollUTF8_2(coll, getData8(status), getModData8(status), TRUE /* useLen */);
+    StrcollUTF8_2 *testCase = new StrcollUTF8_2(coll, getData8(status), getModData8(status), true /* useLen */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1625,10 +1509,10 @@ UPerfFunction* CollPerf2Test::TestStrcollUTF8Similar()
 UPerfFunction* CollPerf2Test::TestGetSortKey()
 {
     UErrorCode status = U_ZERO_ERROR;
-    GetSortKey *testCase = new GetSortKey(coll, getData16(status), TRUE /* useLen */);
+    GetSortKey *testCase = new GetSortKey(coll, getData16(status), true /* useLen */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1636,10 +1520,10 @@ UPerfFunction* CollPerf2Test::TestGetSortKey()
 UPerfFunction* CollPerf2Test::TestGetSortKeyNull()
 {
     UErrorCode status = U_ZERO_ERROR;
-    GetSortKey *testCase = new GetSortKey(coll, getData16(status), FALSE /* useLen */);
+    GetSortKey *testCase = new GetSortKey(coll, getData16(status), false /* useLen */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1650,7 +1534,7 @@ UPerfFunction* CollPerf2Test::TestNextSortKeyPart_4All()
     NextSortKeyPart *testCase = new NextSortKeyPart(coll, getData16(status), 4 /* bufSize */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1661,7 +1545,7 @@ UPerfFunction* CollPerf2Test::TestNextSortKeyPart_4x4()
     NextSortKeyPart *testCase = new NextSortKeyPart(coll, getData16(status), 4 /* bufSize */, 4 /* maxIteration */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1672,7 +1556,7 @@ UPerfFunction* CollPerf2Test::TestNextSortKeyPart_4x8()
     NextSortKeyPart *testCase = new NextSortKeyPart(coll, getData16(status), 4 /* bufSize */, 8 /* maxIteration */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1683,7 +1567,7 @@ UPerfFunction* CollPerf2Test::TestNextSortKeyPart_32All()
     NextSortKeyPart *testCase = new NextSortKeyPart(coll, getData16(status), 32 /* bufSize */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1694,7 +1578,7 @@ UPerfFunction* CollPerf2Test::TestNextSortKeyPart_32x2()
     NextSortKeyPart *testCase = new NextSortKeyPart(coll, getData16(status), 32 /* bufSize */, 2 /* maxIteration */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1705,7 +1589,7 @@ UPerfFunction* CollPerf2Test::TestNextSortKeyPartUTF8_4All()
     NextSortKeyPartUTF8 *testCase = new NextSortKeyPartUTF8(coll, getData8(status), 4 /* bufSize */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1716,7 +1600,7 @@ UPerfFunction* CollPerf2Test::TestNextSortKeyPartUTF8_4x4()
     NextSortKeyPartUTF8 *testCase = new NextSortKeyPartUTF8(coll, getData8(status), 4 /* bufSize */, 4 /* maxIteration */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1727,7 +1611,7 @@ UPerfFunction* CollPerf2Test::TestNextSortKeyPartUTF8_4x8()
     NextSortKeyPartUTF8 *testCase = new NextSortKeyPartUTF8(coll, getData8(status), 4 /* bufSize */, 8 /* maxIteration */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1738,7 +1622,7 @@ UPerfFunction* CollPerf2Test::TestNextSortKeyPartUTF8_32All()
     NextSortKeyPartUTF8 *testCase = new NextSortKeyPartUTF8(coll, getData8(status), 32 /* bufSize */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1749,7 +1633,7 @@ UPerfFunction* CollPerf2Test::TestNextSortKeyPartUTF8_32x2()
     NextSortKeyPartUTF8 *testCase = new NextSortKeyPartUTF8(coll, getData8(status), 32 /* bufSize */, 2 /* maxIteration */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1757,10 +1641,10 @@ UPerfFunction* CollPerf2Test::TestNextSortKeyPartUTF8_32x2()
 UPerfFunction* CollPerf2Test::TestCppCompare()
 {
     UErrorCode status = U_ZERO_ERROR;
-    CppCompare *testCase = new CppCompare(collObj, getData16(status), TRUE /* useLen */);
+    CppCompare *testCase = new CppCompare(collObj, getData16(status), true /* useLen */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1768,10 +1652,10 @@ UPerfFunction* CollPerf2Test::TestCppCompare()
 UPerfFunction* CollPerf2Test::TestCppCompareNull()
 {
     UErrorCode status = U_ZERO_ERROR;
-    CppCompare *testCase = new CppCompare(collObj, getData16(status), FALSE /* useLen */);
+    CppCompare *testCase = new CppCompare(collObj, getData16(status), false /* useLen */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1779,10 +1663,10 @@ UPerfFunction* CollPerf2Test::TestCppCompareNull()
 UPerfFunction* CollPerf2Test::TestCppCompareSimilar()
 {
     UErrorCode status = U_ZERO_ERROR;
-    CppCompare_2 *testCase = new CppCompare_2(collObj, getData16(status), getModData16(status), TRUE /* useLen */);
+    CppCompare_2 *testCase = new CppCompare_2(collObj, getData16(status), getModData16(status), true /* useLen */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1790,10 +1674,10 @@ UPerfFunction* CollPerf2Test::TestCppCompareSimilar()
 UPerfFunction* CollPerf2Test::TestCppCompareUTF8()
 {
     UErrorCode status = U_ZERO_ERROR;
-    CppCompareUTF8 *testCase = new CppCompareUTF8(collObj, getData8(status), TRUE /* useLen */);
+    CppCompareUTF8 *testCase = new CppCompareUTF8(collObj, getData8(status), true /* useLen */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1801,10 +1685,10 @@ UPerfFunction* CollPerf2Test::TestCppCompareUTF8()
 UPerfFunction* CollPerf2Test::TestCppCompareUTF8Null()
 {
     UErrorCode status = U_ZERO_ERROR;
-    CppCompareUTF8 *testCase = new CppCompareUTF8(collObj, getData8(status), FALSE /* useLen */);
+    CppCompareUTF8 *testCase = new CppCompareUTF8(collObj, getData8(status), false /* useLen */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1812,10 +1696,10 @@ UPerfFunction* CollPerf2Test::TestCppCompareUTF8Null()
 UPerfFunction* CollPerf2Test::TestCppCompareUTF8Similar()
 {
     UErrorCode status = U_ZERO_ERROR;
-    CppCompareUTF8_2 *testCase = new CppCompareUTF8_2(collObj, getData8(status), getModData8(status), TRUE /* useLen */);
+    CppCompareUTF8_2 *testCase = new CppCompareUTF8_2(collObj, getData8(status), getModData8(status), true /* useLen */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1823,10 +1707,10 @@ UPerfFunction* CollPerf2Test::TestCppCompareUTF8Similar()
 UPerfFunction* CollPerf2Test::TestCppGetCollationKey()
 {
     UErrorCode status = U_ZERO_ERROR;
-    CppGetCollationKey *testCase = new CppGetCollationKey(collObj, getData16(status), TRUE /* useLen */);
+    CppGetCollationKey *testCase = new CppGetCollationKey(collObj, getData16(status), true /* useLen */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1834,10 +1718,10 @@ UPerfFunction* CollPerf2Test::TestCppGetCollationKey()
 UPerfFunction* CollPerf2Test::TestCppGetCollationKeyNull()
 {
     UErrorCode status = U_ZERO_ERROR;
-    CppGetCollationKey *testCase = new CppGetCollationKey(collObj, getData16(status), FALSE /* useLen */);
+    CppGetCollationKey *testCase = new CppGetCollationKey(collObj, getData16(status), false /* useLen */);
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1847,7 +1731,7 @@ UPerfFunction* CollPerf2Test::TestUniStrSort() {
     UPerfFunction *testCase = new UniStrSort(*collObj, coll, getRandomData16(status));
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1857,7 +1741,7 @@ UPerfFunction* CollPerf2Test::TestStringPieceSortCpp() {
     UPerfFunction *testCase = new StringPieceSortCpp(*collObj, coll, getRandomData8(status));
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1867,7 +1751,7 @@ UPerfFunction* CollPerf2Test::TestStringPieceSortC() {
     UPerfFunction *testCase = new StringPieceSortC(*collObj, coll, getRandomData8(status));
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1877,7 +1761,7 @@ UPerfFunction* CollPerf2Test::TestUniStrBinSearch() {
     UPerfFunction *testCase = new UniStrBinSearch(*collObj, coll, getSortedData16(status));
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1887,7 +1771,7 @@ UPerfFunction* CollPerf2Test::TestStringPieceBinSearchCpp() {
     UPerfFunction *testCase = new StringPieceBinSearchCpp(*collObj, coll, getSortedData8(status));
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1897,7 +1781,7 @@ UPerfFunction* CollPerf2Test::TestStringPieceBinSearchC() {
     UPerfFunction *testCase = new StringPieceBinSearchC(*collObj, coll, getSortedData8(status));
     if (U_FAILURE(status)) {
         delete testCase;
-        return NULL;
+        return nullptr;
     }
     return testCase;
 }
@@ -1914,7 +1798,7 @@ int main(int argc, const char *argv[])
         return status;
     }
 
-    if (test.run() == FALSE){
+    if (test.run() == false){
         fprintf(stderr, "FAILED: Tests could not be run please check the arguments.\n");
         return -1;
     }
